@@ -24,7 +24,7 @@ if (!empty($_POST['blog_id']))
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
-	
+
 	if ($rs->isEmpty()) {
 		$core->error->add(__('No such blog ID'));
 	} else {
@@ -41,33 +41,40 @@ if (!$core->error->flag() && $blog_id && !empty($_POST['del']))
 	} else {
 		try {
 			$core->delBlog($blog_id);
-			http::redirect('blogs.php?del=1');
+			dcPage::addSuccessNotice(sprintf(__('Blog "%s" successfully deleted'), html::escapeHTML($blog_name)));
+
+			http::redirect('blogs.php');
 		} catch (Exception $e) {
 			$core->error->add($e->getMessage());
 		}
 	}
 }
 
-dcPage::open(__('Delete a blog'));
+dcPage::open(__('Delete a blog'),'',
+	dcPage::breadcrumb(
+		array(
+			__('System') => '',
+			__('Blogs') => 'blogs.php',
+			__('Delete a blog') => ''
+		))
+);
 
 if (!$core->error->flag())
 {
 	echo
-	'<h2 class="page-title">'.__('Delete a blog').'</h2>'.
-	'<p class="message">'.__('Warning').'</p>'.
+	'<div class="warning-msg"><p><strong>'.__('Warning').'</strong></p>'.
 	'<p>'.sprintf(__('You are about to delete the blog %s. Every entry, comment and category will be deleted.'),
-	'<strong>'.$blog_id.' ('.$blog_name.')</strong>').'</p>'.
+	'<strong>'.$blog_id.' ('.$blog_name.')</strong>').'</p></div>'.
 	'<p>'.__('Please give your password to confirm the blog deletion.').'</p>';
-	
+
 	echo
 	'<form action="blog_del.php" method="post">'.
 	'<div>'.$core->formNonce().'</div>'.
-	'<p><label for="pwd">'.__('Your password:').' '.
-	form::password('pwd',20,255).'</label></p>'.
+	'<p><label for="pwd">'.__('Your password:').'</label> '.
+	form::password('pwd',20,255).'</p>'.
 	'<p><input type="submit" class="delete" name="del" value="'.__('Delete this blog').'" />'.
 	form::hidden('blog_id',$blog_id).'</p>'.
 	'</form>';
 }
 
 dcPage::close();
-?>
\ No newline at end of file
