@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -14,6 +14,8 @@ require dirname(__FILE__).'/../inc/admin/prepend.php';
 
 dcPage::check('media,media_admin');
 
+$tab = empty($_REQUEST['tab']) ? '' : $_REQUEST['tab'];
+
 $post_id = !empty($_GET['post_id']) ? (integer) $_GET['post_id'] : null;
 if ($post_id) {
 	$post = $core->blog->getPosts(array('post_id'=>$post_id));
@@ -43,24 +45,27 @@ $core_media_writable = false;
 try
 {
 	$core->media = new dcMedia($core);
-	
+
 	if ($id) {
 		$file = $core->media->getFile($id);
 	}
-	
+
 	if ($file === null) {
 		throw new Exception(__('Not a valid file'));
 	}
-	
+
 	$core->media->chdir(dirname($file->relname));
 	$core_media_writable = $core->media->writable();
-	
+
 	# Prepare directories combo box
 	$dirs_combo = array();
-	foreach ($core->media->getRootDirs() as $v) {
-		if ($v->w) {
-			$dirs_combo['/'.$v->relname] = $v->relname;
-		}
+	foreach ($core->media->getDBDirs() as $v) {
+		$dirs_combo['/'.$v] = $v;
+	}
+	# Add parent and direct childs directories if any
+	$core->media->getFSDir();
+	foreach ($core->media->dir['dirs'] as $k => $v) {
+		$dirs_combo['/'.$v->relname] = $v->relname;
 	}
 	ksort($dirs_combo);
 }
@@ -75,7 +80,9 @@ if ($file && !empty($_FILES['upfile']) && $file->editable && $core_media_writabl
 	try {
 		files::uploadStatus($_FILES['upfile']);
 		$core->media->uploadFile($_FILES['upfile']['tmp_name'],$file->basename,null,false,true);
-		http::redirect($page_url.'&id='.$id.'&fupl=1');
+
+		dcPage::addSuccessNotice(__('File has been successfully updated.'));
+		http::redirect($page_url.'&id='.$id);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -85,9 +92,9 @@ if ($file && !empty($_FILES['upfile']) && $file->editable && $core_media_writabl
 if ($file && !empty($_POST['media_file']) && $file->editable && $core_media_writable)
 {
 	$newFile = clone $file;
-	
+
 	$newFile->basename = $_POST['media_file'];
-	
+
 	if ($_POST['media_path']) {
 		$newFile->dir = $_POST['media_path'];
 		$newFile->relname = $_POST['media_path'].'/'.$newFile->basename;
@@ -99,10 +106,12 @@ if ($file && !empty($_POST['media_file']) && $file->editable && $core_media_writ
 	$newFile->media_dt = strtotime($_POST['media_dt']);
 	$newFile->media_dtstr = $_POST['media_dt'];
 	$newFile->media_priv = !empty($_POST['media_private']);
-	
+
 	try {
 		$core->media->updateFile($file,$newFile);
-		http::redirect($page_url.'&id='.$id.'&fupd=1');
+
+		dcPage::addSuccessNotice(__('File has been successfully updated.'));
+		http::redirect($page_url.'&id='.$id.'&tab=media-details-tab');
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -114,7 +123,9 @@ if (!empty($_POST['thumbs']) && $file->media_type == 'image' && $file->editable
 	try {
 		$foo = null;
 		$core->media->mediaFireRecreateEvent($file);
-		http::redirect($page_url.'&id='.$id.'&thumbupd=1');
+
+		dcPage::addSuccessNotice(__('Thumbnails have been successfully updated.'));
+		http::redirect($page_url.'&id='.$id.'&tab=media-details-tab');
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -125,26 +136,58 @@ if (!empty($_POST['unzip']) && $file->type == 'application/zip' && $file->editab
 {
 	try {
 		$unzip_dir = $core->media->inflateZipFile($file,$_POST['inflate_mode'] == 'new');
-		http::redirect($media_page_url.'&d='.$unzip_dir.'&unzipok=1');
+
+		dcPage::addSuccessNotice(__('Zip file has been successfully extracted.'));
+		http::redirect($media_page_url.'&d='.$unzip_dir);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
 }
 
+# Save media insertion settings for the blog
+if (!empty($_POST['save_blog_prefs']))
+{
+	if (!empty($_POST['pref_src'])) {
+		foreach (array_reverse($file->media_thumb) as $s => $v) {
+			if ($v == $_POST['pref_src']) {
+				$core->blog->settings->system->put('media_img_default_size',$s);
+				break;
+			}
+		}
+	}
+	if (!empty($_POST['pref_alignment'])) {
+		$core->blog->settings->system->put('media_img_default_alignment',$_POST['pref_alignment']);
+	}
+	if (!empty($_POST['pref_insertion'])) {
+		$core->blog->settings->system->put('media_img_default_link',($_POST['pref_insertion'] == 'link'));
+	}
+
+	dcPage::addSuccessNotice(__('Default media insertion settings have been successfully updated.'));
+	http::redirect($page_url.'&id='.$id);
+}
+
 # Function to get image title based on meta
-function dcGetImageTitle($file,$pattern)
+function dcGetImageTitle($file,$pattern,$dto_first=false)
 {
 	$res = array();
 	$pattern = preg_split('/\s*;;\s*/',$pattern);
 	$sep = ', ';
-	
+
 	foreach ($pattern as $v) {
 		if ($v == 'Title') {
-			$res[] = $file->media_title;
+			if ($file->media_title != '') {
+				$res[] = $file->media_title;
+			}
 		} elseif ($file->media_meta->{$v}) {
-			$res[] = (string) $file->media_meta->{$v};
+			if ((string) $file->media_meta->{$v} != '') {
+				$res[] = (string) $file->media_meta->{$v};
+			}
 		} elseif (preg_match('/^Date\((.+?)\)$/u',$v,$m)) {
-			$res[] = dt::str($m[1],$file->media_dt);
+			if ($dto_first && ($file->media_meta->DateTimeOriginal != 0)) {
+				$res[] = dt::dt2str($m[1],(string) $file->media_meta->DateTimeOriginal);
+			} else {
+				$res[] = dt::str($m[1],$file->media_dt);
+			}
 		} elseif (preg_match('/^DateTimeOriginal\((.+?)\)$/u',$v,$m) && $file->media_meta->DateTimeOriginal) {
 			$res[] = dt::dt2str($m[1],(string) $file->media_meta->DateTimeOriginal);
 		} elseif (preg_match('/^separator\((.*?)\)$/u',$v,$m)) {
@@ -156,7 +199,13 @@ function dcGetImageTitle($file,$pattern)
 
 /* DISPLAY Main page
 -------------------------------------------------------- */
-$starting_scripts = dcPage::jsLoad('js/_media_item.js');
+$starting_scripts =
+	'<script type="text/javascript">'."\n".
+	"//<![CDATA["."\n".
+	dcPage::jsVar('dotclear.msg.confirm_delete_media',__('Are you sure to delete this media?'))."\n".
+	"//]]>".
+	"</script>".
+	dcPage::jsLoad('js/_media_item.js');
 if ($popup) {
 	$starting_scripts .=
 	dcPage::jsLoad('js/jsToolBar/popup_media.js');
@@ -164,194 +213,257 @@ if ($popup) {
 call_user_func($open_f,__('Media manager'),
 	$starting_scripts.
 	dcPage::jsDatePicker().
-	dcPage::jsPageTabs()
+	($popup ? dcPage::jsPageTabs($tab) : ''),
+	dcPage::breadcrumb(
+		array(
+			html::escapeHTML($core->blog->name) => '',
+			__('Media manager') => html::escapeURL($media_page_url).'&amp;d=',
+			$core->media->breadCrumb(html::escapeURL($media_page_url).'&amp;d=%s').'<span class="page-title">'.$file->basename.'</span>' => ''
+		),
+		array(
+			'home_link' => !$popup,
+			'hl' => false
+		)
+	)
 );
 
+if ($popup) {
+	// Display notices
+	echo dcPage::notices();
+}
+
 if ($file === null) {
 	call_user_func($close_f);
 	exit;
 }
 
 if (!empty($_GET['fupd']) || !empty($_GET['fupl'])) {
-	echo '<p class="message">'.__('File has been successfully updated.').'</p>';
+	dcPage::success(__('File has been successfully updated.'));
 }
 if (!empty($_GET['thumbupd'])) {
-	echo '<p class="message">'.__('Thumbnails have been successfully updated.').'</p>';
+	dcPage::success(__('Thumbnails have been successfully updated.'));
+}
+if (!empty($_GET['blogprefupd'])) {
+	dcPage::success(__('Default media insertion settings have been successfully updated.'));
 }
-
-echo '<h2><a href="'.html::escapeURL($media_page_url).'">'.__('Media manager').'</a>'.
-' / '.$core->media->breadCrumb(html::escapeURL($media_page_url).'&amp;d=%s').
-'<span class="page-title">'.$file->basename.'</span></h2>';
 
 # Insertion popup
 if ($popup)
 {
 	$media_desc = $file->media_title;
-	
+
 	echo
 	'<div id="media-insert" class="multi-part" title="'.__('Insert media item').'">'.
+	'<h3>'.__('Insert media item').'</h3>'.
 	'<form id="media-insert-form" action="" method="get">';
-	
+
+	$media_img_default_size = $core->blog->settings->system->media_img_default_size;
+	if ($media_img_default_size == '') {
+		$media_img_default_size = 'm';
+	}
+	$media_img_default_alignment = $core->blog->settings->system->media_img_default_alignment;
+	if ($media_img_default_alignment == '') {
+		$media_img_default_alignment = 'none';
+	}
+	$media_img_default_link = (boolean)$core->blog->settings->system->media_img_default_link;
+
 	if ($file->media_type == 'image')
 	{
 		$media_type = 'image';
-		$media_desc = dcGetImageTitle($file,$core->blog->settings->system->media_img_title_pattern);
+		$media_desc = dcGetImageTitle($file,
+			$core->blog->settings->system->media_img_title_pattern,
+			$core->blog->settings->system->media_img_use_dto_first);
 		if ($media_desc == $file->basename) {
 			$media_desc = '';
 		}
-		
+
 		echo
 		'<h3>'.__('Image size:').'</h3> ';
-		
+
 		$s_checked = false;
 		echo '<p>';
 		foreach (array_reverse($file->media_thumb) as $s => $v) {
-			$s_checked = ($s == 'm');
+			$s_checked = ($s == $media_img_default_size);
 			echo '<label class="classic">'.
 			form::radio(array('src'),html::escapeHTML($v),$s_checked).' '.
 			$core->media->thumb_sizes[$s][2].'</label><br /> ';
 		}
-		$s_checked = (!isset($file->media_thumb['m']));
+		$s_checked = (!isset($file->media_thumb[$media_img_default_size]));
 		echo '<label class="classic">'.
 		form::radio(array('src'),$file->file_url,$s_checked).' '.__('original').'</label><br /> ';
 		echo '</p>';
-		
-		
-		echo '<h3>'.__('Image alignment').'</h3>';
+
+		echo
+		'<div class="two-boxes">'.
+		'<h3>'.__('Image alignment').'</h3>';
 		$i_align = array(
-			'none' => array(__('None'),1),
-			'left' => array(__('Left'),0),
-			'right' => array(__('Right'),0),
-			'center' => array(__('Center'),0)
+			'none' => array(__('None'),($media_img_default_alignment == 'none' ? 1 : 0)),
+			'left' => array(__('Left'),($media_img_default_alignment == 'left' ? 1 : 0)),
+			'right' => array(__('Right'),($media_img_default_alignment == 'right' ? 1 : 0)),
+			'center' => array(__('Center'),($media_img_default_alignment == 'center' ? 1 : 0))
 		);
-		
+
 		echo '<p>';
 		foreach ($i_align as $k => $v) {
 			echo '<label class="classic">'.
 			form::radio(array('alignment'),$k,$v[1]).' '.$v[0].'</label><br /> ';
 		}
 		echo '</p>';
-		
+		echo '</div>';
+
 		echo
+		'<div class="two-boxes">'.
 		'<h3>'.__('Image insertion').'</h3>'.
 		'<p>'.
-		'<label for="insert1" class="classic">'.form::radio(array('insertion','insert1'),'simple',true).
+		'<label for="insert1" class="classic">'.form::radio(array('insertion','insert1'),'simple',!$media_img_default_link).
 		__('As a single image').'</label><br />'.
-		'<label for="insert2" class="classic">'.form::radio(array('insertion','insert2'),'link',false).
-		__('As a link to original image').'</label>'.
-		'</p>';
+		'<label for="insert2" class="classic">'.form::radio(array('insertion','insert2'),'link',$media_img_default_link).
+		__('As a link to the original image').'</label>'.
+		'</p>'.
+		'</div>';
 	}
 	elseif ($file->type == 'audio/mpeg3')
 	{
 		$media_type = 'mp3';
-		
-		echo '<h3>'.__('MP3 disposition').'</h3>'.
-		'<p class="message">'.__("Please note that you cannot insert mp3 files with visual editor.").'</p>';
-		
+
+		echo
+		'<div class="two-boxes">'.
+		'<h3>'.__('MP3 disposition').'</h3>';
+		dcPage::message(__("Please note that you cannot insert mp3 files with visual editor."),false);
+
 		$i_align = array(
-			'none' => array(__('None'),0),
-			'left' => array(__('Left'),0),
-			'right' => array(__('Right'),0),
-			'center' => array(__('Center'),1)
+			'none' => array(__('None'),($media_img_default_alignment == 'none' ? 1 : 0)),
+			'left' => array(__('Left'),($media_img_default_alignment == 'left' ? 1 : 0)),
+			'right' => array(__('Right'),($media_img_default_alignment == 'right' ? 1 : 0)),
+			'center' => array(__('Center'),($media_img_default_alignment == 'center' ? 1 : 0))
 		);
-		
+
 		echo '<p>';
 		foreach ($i_align as $k => $v) {
-			echo '<label for="alignment" class="classic">'.
+			echo '<label class="classic">'.
 			form::radio(array('alignment'),$k,$v[1]).' '.$v[0].'</label><br /> ';
 		}
-		
+
 		$public_player_style = unserialize($core->blog->settings->themes->mp3player_style);
 		$public_player = dcMedia::mp3player($file->file_url,$core->blog->getQmarkURL().'pf=player_mp3.swf',$public_player_style);
 		echo form::hidden('public_player',html::escapeHTML($public_player));
 		echo '</p>';
+		echo '</div>';
 	}
 	elseif ($file->type == 'video/x-flv' || $file->type == 'video/mp4' || $file->type == 'video/x-m4v')
 	{
 		$media_type = 'flv';
-		
-		echo
-		'<p class="message">'.__("Please note that you cannot insert video files with visual editor.").'</p>';
-		
+
+		dcPage::message(__("Please note that you cannot insert video files with visual editor."),false);
+
 		echo
+		'<div class="two-boxes">'.
 		'<h3>'.__('Video size').'</h3>'.
-		'<p><label for="video_w" class="classic">'.__('Width:').' '.
+		'<p><label for="video_w" class="classic">'.__('Width:').'</label> '.
 		form::field('video_w',3,4,400).'  '.
-		'<label for="video_h" class="classic">'.__('Height:').' '.
+		'<label for="video_h" class="classic">'.__('Height:').'</label> '.
 		form::field('video_h',3,4,300).
-		'</p>';
-		
-		echo '<h3>'.__('Video disposition').'</h3>';
-		
+		'</p>'.
+		'</div>';
+
+
+		echo
+		'<div class="two-boxes">'.
+		'<h3>'.__('Video disposition').'</h3>';
+
 		$i_align = array(
-			'none' => array(__('None'),0),
-			'left' => array(__('Left'),0),
-			'right' => array(__('Right'),0),
-			'center' => array(__('Center'),1)
+			'none' => array(__('None'),($media_img_default_alignment == 'none' ? 1 : 0)),
+			'left' => array(__('Left'),($media_img_default_alignment == 'left' ? 1 : 0)),
+			'right' => array(__('Right'),($media_img_default_alignment == 'right' ? 1 : 0)),
+			'center' => array(__('Center'),($media_img_default_alignment == 'center' ? 1 : 0))
 		);
-		
+
 		echo '<p>';
 		foreach ($i_align as $k => $v) {
-			echo '<label for="alignment" class="classic">'.
+			echo '<label class="classic">'.
 			form::radio(array('alignment'),$k,$v[1]).' '.$v[0].'</label><br /> ';
 		}
-		
+
 		$public_player_style = unserialize($core->blog->settings->themes->flvplayer_style);
 		$public_player = dcMedia::flvplayer($file->file_url,$core->blog->getQmarkURL().'pf=player_flv.swf',$public_player_style);
 		echo form::hidden('public_player',html::escapeHTML($public_player));
 		echo '</p>';
+		echo '</div>';
 	}
 	else
 	{
 		$media_type = 'default';
 		echo '<p>'.__('Media item will be inserted as a link.').'</p>';
 	}
-	
+
 	echo
-	'<p><a id="media-insert-cancel" class="button" href="#">'.__('Cancel').'</a> - '.
-	'<strong><a id="media-insert-ok" class="button" href="#">'.__('Insert').'</a></strong>'.
+	'<p>'.
+	'<a id="media-insert-ok" class="button submit" href="#">'.__('Insert').'</a> '.
+	'<a id="media-insert-cancel" class="button" href="#">'.__('Cancel').'</a>'.
 	form::hidden(array('type'),html::escapeHTML($media_type)).
 	form::hidden(array('title'),html::escapeHTML($file->media_title)).
 	form::hidden(array('description'),html::escapeHTML($media_desc)).
 	form::hidden(array('url'),$file->file_url).
 	'</p>';
-	
-	echo '</form></div>';
+
+	echo '</form>';
+
+	if ($media_type != 'default') {
+		echo
+		'<div class="border-top">'.
+		'<form id="save_settings" action="'.html::escapeURL($page_url).'" method="post">'.
+		'<p>'.__('Make current settings as default').' '.
+		'<input class="reset" type="submit" name="save_blog_prefs" value="'.__('OK').'" />'.
+		form::hidden(array('pref_src'),'').
+		form::hidden(array('pref_alignment'),'').
+		form::hidden(array('pref_insertion'),'').
+		form::hidden(array('id'),$id).
+		$core->formNonce().'</p>'.
+		'</form>'.'</div>';
+	}
+
+	echo '</div>';
 }
 
+if ($popup) {
+	echo
+	'<div class="multi-part" title="'.__('Media details').'" id="media-details-tab">';
+} else {
+	echo '<h3 class="out-of-screen-if-js">'.__('Media details').'</h3>';
+}
 echo
-'<div class="multi-part" title="'.__('Media details').'" id="media-details-tab">'.
-'<p id="media-icon"><img src="'.$file->media_icon.'" alt="" /></p>';
+'<p id="media-icon"><img src="'.$file->media_icon.'?'.time()*rand().'" alt="" /></p>';
 
 echo
-'<div id="media-details">';
+'<div id="media-details">'.
+'<div class="near-icon">';
 
 if ($file->media_image)
 {
 	$thumb_size = !empty($_GET['size']) ? $_GET['size'] : 's';
-	
+
 	if (!isset($core->media->thumb_sizes[$thumb_size]) && $thumb_size != 'o') {
 		$thumb_size = 's';
 	}
-	
+
+	if (isset($file->media_thumb[$thumb_size])) {
+		echo '<p><img src="'.$file->media_thumb[$thumb_size].'?'.time()*rand().'" alt="" /></p>';
+	} elseif ($thumb_size == 'o') {
+		$S = getimagesize($file->file);
+		$class = ($S[1] > 500) ? ' class="overheight"' : '';
+		unset($S);
+		echo '<p id="media-original-image"'.$class.'><img src="'.$file->file_url.'?'.time()*rand().'" alt="" /></p>';
+	}
+
 	echo '<p>'.__('Available sizes:').' ';
 	foreach (array_reverse($file->media_thumb) as $s => $v)
 	{
 		$strong_link = ($s == $thumb_size) ? '<strong>%s</strong>' : '%s';
 		printf($strong_link,'<a href="'.html::escapeURL($page_url).
-		'&amp;id='.$id.'&amp;size='.$s.'">'.$core->media->thumb_sizes[$s][2].'</a> | ');
+		'&amp;id='.$id.'&amp;size='.$s.'&amp;tab=media-details-tab">'.$core->media->thumb_sizes[$s][2].'</a> | ');
 	}
-	echo '<a href="'.html::escapeURL($page_url).'&amp;id='.$id.'&amp;size=o">'.__('original').'</a>';
+	echo '<a href="'.html::escapeURL($page_url).'&amp;id='.$id.'&amp;size=o&amp;tab=media-details-tab">'.__('original').'</a>';
 	echo '</p>';
-	
-	if (isset($file->media_thumb[$thumb_size])) {
-		echo '<p><img src="'.$file->media_thumb[$thumb_size].'" alt="" /></p>';
-	} elseif ($thumb_size == 'o') {
-		$S = getimagesize($file->file);
-		$class = ($S[1] > 500) ? ' class="overheight"' : '';
-		unset($S);
-		echo '<p id="media-original-image"'.$class.'><img src="'.$file->file_url.'" alt="" /></p>';
-	}
 }
 
 if ($file->type == 'audio/mpeg3')
@@ -376,8 +488,8 @@ echo
 if (empty($_GET['find_posts']))
 {
 	echo
-	'<p><strong><a href="'.html::escapeHTML($page_url).'&amp;id='.$id.'&amp;find_posts=1">'.
-	__('Show entries containing this media').'</a></strong></p>';
+	'<p><a class="button" href="'.html::escapeHTML($page_url).'&amp;id='.$id.'&amp;find_posts=1&amp;tab=media-details-tab">'.
+	__('Show entries containing this media').'</a></p>';
 }
 else
 {
@@ -390,7 +502,7 @@ else
 			"OR post_content_xhtml LIKE '%".$core->con->escape($file->relname)."%' ".
 			"OR post_excerpt_xhtml LIKE '%".$core->con->escape($file->relname)."%' "
 	);
-	
+
 	if ($file->media_image)
 	{ # We look for thumbnails too
 		if (preg_match('#^http(s)?://#',$core->blog->settings->system->public_url)) {
@@ -404,11 +516,11 @@ else
 			$params['sql'] .= "OR post_excerpt_xhtml LIKE '%".$core->con->escape($v)."%' ";
 		}
 	}
-	
+
 	$params['sql'] .= ') ';
-	
+
 	$rs = $core->blog->getPosts($params);
-	
+
 	if ($rs->isEmpty())
 	{
 		echo '<p>'.__('No entry seems contain this media.').'</p>';
@@ -417,10 +529,25 @@ else
 	{
 		echo '<ul>';
 		while ($rs->fetch()) {
-			echo '<li><a href="'.$core->getPostAdminURL($rs->post_type,$rs->post_id).'">'.
-			$rs->post_title.'</a>'.
-			($rs->post_type != 'post' ? ' ('.html::escapeHTML($rs->post_type).')' : '').
-			' - '.dt::dt2str(__('%Y-%m-%d %H:%M'),$rs->post_dt).'</li>';
+			$img = '<img alt="%1$s" title="%1$s" src="images/%2$s" />';
+			switch ($rs->post_status) {
+				case 1:
+					$img_status = sprintf($img,__('published'),'check-on.png');
+					break;
+				case 0:
+					$img_status = sprintf($img,__('unpublished'),'check-off.png');
+					break;
+				case -1:
+					$img_status = sprintf($img,__('scheduled'),'scheduled.png');
+					break;
+				case -2:
+					$img_status = sprintf($img,__('pending'),'check-wrn.png');
+					break;
+			}
+			echo '<li>'.$img_status.' '.'<a href="'.$core->getPostAdminURL($rs->post_type,$rs->post_id).'">'.
+				$rs->post_title.'</a>'.
+				($rs->post_type != 'post' ? ' ('.html::escapeHTML($rs->post_type).')' : '').
+				' - '.dt::dt2str(__('%Y-%m-%d %H:%M'),$rs->post_dt).'</li>';
 		}
 		echo '</ul>';
 	}
@@ -429,83 +556,87 @@ else
 if ($file->type == 'image/jpeg')
 {
 	echo '<h3>'.__('Image details').'</h3>';
-	
-	if (count($file->media_meta) == 0)
+
+	$details = '';
+	if (count($file->media_meta) > 0)
 	{
-		echo '<p>'.__('No detail').'</p>';
-	}
-	else
-	{
-		echo '<ul>';
 		foreach ($file->media_meta as $k => $v)
 		{
 			if ((string) $v) {
-				echo '<li><strong>'.$k.':</strong> '.html::escapeHTML($v).'</li>';
+				$details .= '<li><strong>'.$k.':</strong> '.html::escapeHTML($v).'</li>';
 			}
 		}
-		echo '</ul>';
+	}
+	if ($details) {
+		echo '<ul>'.$details.'</ul>';
+	} else {
+		echo '<p>'.__('No detail').'</p>';
 	}
 }
 
+echo '</div>';
+
+echo '<h3>'.__('Updates and modifications').'</h3>';
+
 if ($file->editable && $core_media_writable)
 {
 	if ($file->media_type == 'image')
 	{
 		echo
-		'<form class="clear" action="'.html::escapeURL($page_url).'" method="post">'.
-		'<fieldset><legend>'.__('Update thumbnails').'</legend>'.
+		'<form class="clear fieldset" action="'.html::escapeURL($page_url).'" method="post">'.
+		'<h4>'.__('Update thumbnails').'</h4>'.
 		'<p>'.__('This will create or update thumbnails for this image.').'</p>'.
 		'<p><input type="submit" name="thumbs" value="'.__('Update thumbnails').'" />'.
 		form::hidden(array('id'),$id).
 		$core->formNonce().'</p>'.
-		'</fieldset></form>';
+		'</form>';
 	}
-	
+
 	if ($file->type == 'application/zip')
 	{
 		$inflate_combo = array(
 			__('Extract in a new directory') => 'new',
 			__('Extract in current directory') => 'current'
 		);
-		
+
 		echo
-		'<form class="clear" id="file-unzip" action="'.html::escapeURL($page_url).'" method="post">'.
-		'<fieldset><legend>'.__('Extract archive').'</legend>'.
+		'<form class="clear fieldset" id="file-unzip" action="'.html::escapeURL($page_url).'" method="post">'.
+		'<h4>'.__('Extract archive').'</h4>'.
 		'<ul>'.
 		'<li><strong>'.__('Extract in a new directory').'</strong> : '.
 		__('This will extract archive in a new directory that should not exist yet.').'</li>'.
 		'<li><strong>'.__('Extract in current directory').'</strong> : '.
 		__('This will extract archive in current directory and will overwrite existing files or directory.').'</li>'.
 		'</ul>'.
-		'<p><label for="inflate_mode" class="classic">'.__('Extract mode:').' '.
-		form::combo('inflate_mode',$inflate_combo,'new').'</label> '.
+		'<p><label for="inflate_mode" class="classic">'.__('Extract mode:').'</label> '.
+		form::combo('inflate_mode',$inflate_combo,'new').
 		'<input type="submit" name="unzip" value="'.__('Extract').'" />'.
 		form::hidden(array('id'),$id).
 		$core->formNonce().'</p>'.
-		'</fieldset></form>';
+		'</form>';
 	}
-	
+
 	echo
-	'<form class="clear" action="'.html::escapeURL($page_url).'" method="post">'.
-	'<fieldset><legend>'.__('Change media properties').'</legend>'.
-	'<p><label for="media_file">'.__('File name:').
-	form::field('media_file',30,255,html::escapeHTML($file->basename)).'</label></p>'.
-	'<p><label for="media_title">'.__('File title:').
-	form::field('media_title',30,255,html::escapeHTML($file->media_title)).'</label></p>'.
-	'<p><label for="media_dt">'.__('File date:').
-	form::field('media_dt',16,16,html::escapeHTML($file->media_dtstr)).'</label></p>'.
+	'<form class="clear fieldset" action="'.html::escapeURL($page_url).'" method="post">'.
+	'<h4>'.__('Change media properties').'</h4>'.
+	'<p><label for="media_file">'.__('File name:').'</label>'.
+	form::field('media_file',30,255,html::escapeHTML($file->basename)).'</p>'.
+	'<p><label for="media_title">'.__('File title:').'</label>'.
+	form::field('media_title',30,255,html::escapeHTML($file->media_title)).'</p>'.
+	'<p><label for="media_dt">'.__('File date:').'</label>'.
+	form::field('media_dt',16,16,html::escapeHTML($file->media_dtstr)).'</p>'.
 	'<p><label for="media_private" class="classic">'.form::checkbox('media_private',1,$file->media_priv).' '.
 	__('Private').'</label></p>'.
-	'<p><label for="media_path">'.__('New directory:').
-	form::combo('media_path',$dirs_combo,dirname($file->relname)).'</label></p>'.
+	'<p><label for="media_path">'.__('New directory:').'</label>'.
+	form::combo('media_path',$dirs_combo,dirname($file->relname)).'</p>'.
 	'<p><input type="submit" accesskey="s" value="'.__('Save').'" />'.
 	form::hidden(array('id'),$id).
 	$core->formNonce().'</p>'.
-	'</fieldset></form>';
-	
+	'</form>';
+
 	echo
-	'<form class="clear" action="'.html::escapeURL($page_url).'" method="post" enctype="multipart/form-data">'.
-	'<fieldset><legend>'.__('Change file').'</legend>'.
+	'<form class="clear fieldset" action="'.html::escapeURL($page_url).'" method="post" enctype="multipart/form-data">'.
+	'<h4>'.__('Change file').'</h4>'.
 	'<div>'.form::hidden(array('MAX_FILE_SIZE'),DC_MAX_UPLOAD_SIZE).'</div>'.
 	'<p><label for="upfile">'.__('Choose a file:').
 	' ('.sprintf(__('Maximum size %s'),files::size(DC_MAX_UPLOAD_SIZE)).') '.
@@ -514,15 +645,30 @@ if ($file->editable && $core_media_writable)
 	'<p><input type="submit" value="'.__('Send').'" />'.
 	form::hidden(array('id'),$id).
 	$core->formNonce().'</p>'.
-	'</fieldset></form>';
+	'</form>';
+
+	if ($file->del) {
+		echo
+		'<form id="delete-form" method="post" action="'.html::escapeURL($media_page_url).
+		'&amp;d='.rawurlencode(dirname($file->relname)).
+		'&amp;remove='.rawurlencode($file->basename).'">'.
+		'<p><input name="delete" type="submit" class="delete" value="'.__('Delete this media').'" />'.
+		form::hidden('remove',rawurlencode($file->basename)).
+		form::hidden('rmyes',1).
+		$core->formNonce().'</p>'.
+		'</form>';
+	}
+
 
 	# --BEHAVIOR-- adminMediaItemForm
 	$core->callBehavior('adminMediaItemForm',$file);
 }
 
 echo
-'</div>'.
 '</div>';
+if ($popup) {
+	echo
+	'</div>';
+}
 
 call_user_func($close_f);
-?>
\ No newline at end of file
