@@ -46,60 +46,63 @@ try {
 if (!$core->error->flag())
 {
 	# Filter form we'll put in html_block
-	$users_combo = $categories_combo = array();
-	$users_combo['-'] = $categories_combo['-'] = '';
-	while ($users->fetch())
-	{
-		$user_cn = dcUtils::getUserCN($users->user_id,$users->user_name,
-		$users->user_firstname,$users->user_displayname);
-		
-		if ($user_cn != $users->user_id) {
-			$user_cn .= ' ('.$users->user_id.')';
-		}
-		
-		$users_combo[$user_cn] = $users->user_id; 
-	}
-	
-	$categories_combo[__('None')] = 'NULL';
-	while ($categories->fetch()) {
-		$categories_combo[str_repeat('&nbsp;&nbsp;',$categories->level-1).($categories->level-1 == 0 ? '' : '&bull; ').
-			html::escapeHTML($categories->cat_title).
-			' ('.$categories->nb_post.')'] = $categories->cat_id;
-	}
-	
-	$status_combo = array(
-	'-' => ''
+	$users_combo = array_merge(
+		array('-' => ''),
+		dcAdminCombos::getUsersCombo($users)
 	);
-	foreach ($core->blog->getAllPostStatus() as $k => $v) {
-		$status_combo[$v] = (string) $k;
+
+	$categories_combo = array_merge(
+		array(
+			new formSelectOption('-',''),
+			new formSelectOption(__('(No cat)'),'NULL')),
+		dcAdminCombos::getCategoriesCombo($categories,false)
+	);
+	$categories_values = array();
+	foreach ($categories_combo as $cat) {
+		if (isset($cat->value)) {
+			$categories_values[$cat->value]=true;
+		}
 	}
-	
+
+	$status_combo = array_merge(
+		array('-' => ''),
+		dcAdminCombos::getPostStatusesCombo()
+	);
+
 	$selected_combo = array(
 	'-' => '',
-	__('selected') => '1',
-	__('not selected') => '0'
+	__('Selected') => '1',
+	__('Not selected') => '0'
 	);
-	
+
+	$attachment_combo = array(
+	'-' => '',
+	__('With attachments') => '1',
+	__('Without attachments') => '0'
+	);
+
 	# Months array
-	$dt_m_combo['-'] = '';
-	while ($dates->fetch()) {
-		$dt_m_combo[dt::str('%B %Y',$dates->ts())] = $dates->year().$dates->month();
-	}
-	
-	$lang_combo['-'] = '';
-	while ($langs->fetch()) {
-		$lang_combo[$langs->post_lang] = $langs->post_lang;
-	}
-	
+	$dt_m_combo = array_merge(
+		array('-' => ''),
+		dcAdminCombos::getDatesCombo($dates)
+	);
+
+	$lang_combo = array_merge(
+		array('-' => ''),
+		dcAdminCombos::getLangsCombo($langs,false)
+	);
+
 	$sortby_combo = array(
 	__('Date') => 'post_dt',
 	__('Title') => 'post_title',
 	__('Category') => 'cat_title',
 	__('Author') => 'user_id',
 	__('Status') => 'post_status',
-	__('Selected') => 'post_selected'
+	__('Selected') => 'post_selected',
+	__('Number of comments') => 'nb_comment',
+	__('Number of trackbacks') => 'nb_trackback'
 	);
-	
+
 	$order_combo = array(
 	__('Descending') => 'desc',
 	__('Ascending') => 'asc'
@@ -107,35 +110,12 @@ if (!$core->error->flag())
 }
 
 # Actions combo box
-$combo_action = array();
-if ($core->auth->check('publish,contentadmin',$core->blog->id))
-{
-	$combo_action[__('Status')] = array(
-		__('Publish') => 'publish',
-		__('Unpublish') => 'unpublish',
-		__('Schedule') => 'schedule',
-		__('Mark as pending') => 'pending'
-	);
-}
-$combo_action[__('Mark')] = array(
-	__('Mark as selected') => 'selected',
-	__('Mark as unselected') => 'unselected'
-);
-$combo_action[__('Change')] = array(
-	__('Change category') => 'category',
-	__('Change language') => 'lang');
-if ($core->auth->check('admin',$core->blog->id))
-{
-	$combo_action[__('Change')] = array_merge($combo_action[__('Change')],
-		array(__('Change author') => 'author'));
-}
-if ($core->auth->check('delete,contentadmin',$core->blog->id))
-{
-	$combo_action[__('Delete')] = array(__('Delete') => 'delete');
-}
 
-# --BEHAVIOR-- adminPostsActionsCombo
-$core->callBehavior('adminPostsActionsCombo',array(&$combo_action));
+$posts_actions_page = new dcPostsActionsPage($core,'posts.php');
+
+if ($posts_actions_page->process()) {
+	return;
+}
 
 /* Get posts
 -------------------------------------------------------- */
@@ -143,6 +123,7 @@ $user_id = !empty($_GET['user_id']) ?	$_GET['user_id'] : '';
 $cat_id = !empty($_GET['cat_id']) ?	$_GET['cat_id'] : '';
 $status = isset($_GET['status']) ?	$_GET['status'] : '';
 $selected = isset($_GET['selected']) ?	$_GET['selected'] : '';
+$attachment = isset($_GET['attachment']) ?	$_GET['attachment'] : '';
 $month = !empty($_GET['month']) ?		$_GET['month'] : '';
 $lang = !empty($_GET['lang']) ?		$_GET['lang'] : '';
 $sortby = !empty($_GET['sortby']) ?	$_GET['sortby'] : 'post_dt';
@@ -150,7 +131,7 @@ $order = !empty($_GET['order']) ?		$_GET['order'] : 'desc';
 
 $show_filters = false;
 
-$page = !empty($_GET['page']) ? (integer) $_GET['page'] : 1;
+$page = !empty($_GET['page']) ? max(1,(integer) $_GET['page']) : 1;
 $nb_per_page =  30;
 
 if (!empty($_GET['nb']) && (integer) $_GET['nb'] > 0) {
@@ -172,7 +153,7 @@ if ($user_id !== '' && in_array($user_id,$users_combo)) {
 }
 
 # - Categories filter
-if ($cat_id !== '' && in_array($cat_id,$categories_combo)) {
+if ($cat_id !== '' && isset($categories_values[$cat_id])) {
 	$params['cat_id'] = $cat_id;
 	$show_filters = true;
 } else {
@@ -195,6 +176,15 @@ if ($selected !== '' && in_array($selected,$selected_combo)) {
 	$selected='';
 }
 
+# - Selected filter
+if ($attachment !== '' && in_array($attachment,$attachment_combo)) {
+	$params['media'] = $attachment;
+	$params['link_type'] = 'attachment';
+	$show_filters = true;
+} else {
+	$attachment='';
+}
+
 # - Month filter
 if ($month !== '' && in_array($month,$dt_m_combo)) {
 	$params['post_month'] = substr($month,4,2);
@@ -219,7 +209,7 @@ if ($sortby !== '' && in_array($sortby,$sortby_combo)) {
 	} else {
 		$order='desc';
 	}
-	
+
 	if ($sortby != 'post_dt' || $order != 'desc') {
 		$show_filters = true;
 	}
@@ -239,76 +229,93 @@ try {
 
 /* DISPLAY
 -------------------------------------------------------- */
-$starting_script = dcPage::jsLoad('js/_posts_list.js');
-if (!$show_filters) {
-	$starting_script .= dcPage::jsLoad('js/filter-controls.js');
+
+$form_filter_title = __('Show filters and display options');
+$starting_script  = dcPage::jsLoad('js/_posts_list.js');
+$starting_script .= dcPage::jsLoad('js/filter-controls.js');
+$starting_script .=
+	'<script type="text/javascript">'."\n".
+	"//<![CDATA["."\n".
+	dcPage::jsVar('dotclear.msg.show_filters', $show_filters ? 'true':'false')."\n".
+	dcPage::jsVar('dotclear.msg.filter_posts_list',$form_filter_title)."\n".
+	dcPage::jsVar('dotclear.msg.cancel_the_filter',__('Cancel filters and display options'))."\n".
+	"//]]>".
+	"</script>";
+
+dcPage::open(__('Entries'),$starting_script,
+	dcPage::breadcrumb(
+		array(
+			html::escapeHTML($core->blog->name) => '',
+			__('Entries') => ''
+		))
+);
+if (!empty($_GET['upd'])) {
+	dcPage::success(__('Selected entries have been successfully updated.'));
+} elseif (!empty($_GET['del'])) {
+	dcPage::success(__('Selected entries have been successfully deleted.'));
 }
-
-dcPage::open(__('Entries'),$starting_script);
-
 if (!$core->error->flag())
 {
-	echo 
-	'<h2>'.html::escapeHTML($core->blog->name).' &rsaquo; <span class="page-title">'.__('Entries').'</span></h2>'.
-	'<p class="top-add"><a class="button add" href="post.php">'.__('New entry').'</a></p>';
-	
-	if (!$show_filters) {
-		echo '<p><a id="filter-control" class="form-control" href="#">'.
-		__('Filters').'</a></p>';
-	}
-	
 	echo
+	'<p class="top-add"><a class="button add" href="post.php">'.__('New entry').'</a></p>'.
 	'<form action="posts.php" method="get" id="filters-form">'.
-	'<fieldset><legend>'.__('Filters').'</legend>'.
-	'<div class="three-cols">'.
-	'<div class="col">'.
-	'<label for="user_id">'.__('Author:').
-	form::combo('user_id',$users_combo,$user_id).'</label> '.
-	'<label for="cat_id">'.__('Category:').
-	form::combo('cat_id',$categories_combo,$cat_id).'</label> '.
-	'<label for="status">'.__('Status:').
-	form::combo('status',$status_combo,$status).'</label> '.
+	'<h3 class="out-of-screen-if-js">'.$form_filter_title.'</h3>'.
+
+	'<div class="table">'.
+	'<div class="cell">'.
+	'<h4>'.__('Filters').'</h4>'.
+	'<p><label for="user_id" class="ib">'.__('Author:').'</label> '.
+	form::combo('user_id',$users_combo,$user_id).'</p>'.
+	'<p><label for="cat_id" class="ib">'.__('Category:').'</label> '.
+	form::combo('cat_id',$categories_combo,$cat_id).'</p>'.
+	'<p><label for="status" class="ib">'.__('Status:').'</label> ' .
+	form::combo('status',$status_combo,$status).'</p> '.
 	'</div>'.
-	
-	'<div class="col">'.
-	'<label for="selected">'.__('Selected:').
-	form::combo('selected',$selected_combo,$selected).'</label> '.
-	'<label for="month">'.__('Month:').
-	form::combo('month',$dt_m_combo,$month).'</label> '.
-	'<label for="lang">'.__('Lang:').
-	form::combo('lang',$lang_combo,$lang).'</label> '.
+
+	'<div class="cell filters-sibling-cell">'.
+	'<p><label for="selected" class="ib">'.__('Selected:').'</label> '.
+	form::combo('selected',$selected_combo,$selected).'</p>'.
+	'<p><label for="attachment" class="ib">'.__('Attachments:').'</label> '.
+	form::combo('attachment',$attachment_combo,$attachment).'</p>'.
+	'<p><label for="month" class="ib">'.__('Month:').'</label> '.
+	form::combo('month',$dt_m_combo,$month).'</p>'.
+	'<p><label for="lang" class="ib">'.__('Lang:').'</label> '.
+	form::combo('lang',$lang_combo,$lang).'</p> '.
 	'</div>'.
-	
-	'<div class="col">'.
-	'<p><label for="sortby">'.__('Order by:').
-	form::combo('sortby',$sortby_combo,$sortby).'</label> '.
-	'<label for="order">'.__('Sort:').
-	form::combo('order',$order_combo,$order).'</label></p>'.
-	'<p><label for="nb" class="classic">'.	form::field('nb',3,3,$nb_per_page).' '.
-	__('Entries per page').'</label></p> '.
-	'<p><input type="submit" value="'.__('Apply filters').'" /></p>'.
+
+	'<div class="cell filters-options">'.
+	'<h4>'.__('Display options').'</h4>'.
+	'<p><label for="sortby" class="ib">'.__('Order by:').'</label> '.
+	form::combo('sortby',$sortby_combo,$sortby).'</p>'.
+	'<p><label for="order" class="ib">'.__('Sort:').'</label> '.
+	form::combo('order',$order_combo,$order).'</p>'.
+	'<p><span class="label ib">'.__('Show').'</span> <label for="nb" class="classic">'.
+	form::field('nb',3,3,$nb_per_page).' '.
+	__('entries per page').'</label></p>'.
 	'</div>'.
 	'</div>'.
-	'<br class="clear" />'. //Opera sucks
-	'</fieldset>'.
+
+	'<p><input type="submit" value="'.__('Apply filters and display options').'" />'.
+	'<br class="clear" /></p>'. //Opera sucks
 	'</form>';
-	
+
 	# Show posts
 	$post_list->display($page,$nb_per_page,
-	'<form action="posts_actions.php" method="post" id="form-entries">'.
-	
+	'<form action="posts.php" method="post" id="form-entries">'.
+
 	'%s'.
-	
+
 	'<div class="two-cols">'.
 	'<p class="col checkboxes-helpers"></p>'.
-	
+
 	'<p class="col right"><label for="action" class="classic">'.__('Selected entries action:').'</label> '.
-	form::combo('action',$combo_action).
+	form::combo('action',$posts_actions_page->getCombo()).
 	'<input type="submit" value="'.__('ok').'" /></p>'.
 	form::hidden(array('user_id'),$user_id).
 	form::hidden(array('cat_id'),$cat_id).
 	form::hidden(array('status'),$status).
 	form::hidden(array('selected'),$selected).
+	form::hidden(array('attachment'),$attachment).
 	form::hidden(array('month'),$month).
 	form::hidden(array('lang'),$lang).
 	form::hidden(array('sortby'),$sortby).
@@ -317,10 +324,10 @@ if (!$core->error->flag())
 	form::hidden(array('nb'),$nb_per_page).
 	$core->formNonce().
 	'</div>'.
-	'</form>'
+	'</form>',
+	$show_filters
 	);
 }
 
 dcPage::helpBlock('core_posts');
 dcPage::close();
-?>
