@@ -68,6 +68,7 @@ try {
 $_lang = $core->blog->settings->system->lang;
 $_lang = preg_match('/^[a-z]{2}(-[a-z]{2})?$/',$_lang) ? $_lang : 'en';
 
+l10n::lang($_lang);
 if (l10n::set(dirname(__FILE__).'/../../locales/'.$_lang.'/date') === false && $_lang != 'en') {
 	l10n::set(dirname(__FILE__).'/../../locales/en/date');
 }
@@ -99,7 +100,7 @@ if ($__parent_theme) {
 		$__parent_theme = null;
 	}
 }
-	
+
 # If theme doesn't exist, stop everything
 if (!$core->themes->moduleExists($__theme)) {
 	__error(__('Default theme not found.')
@@ -143,9 +144,9 @@ $core->url->mode = $core->blog->settings->system->url_scan;
 try {
 	# --BEHAVIOR-- publicBeforeDocument
 	$core->callBehavior('publicBeforeDocument',$core);
-	
+
 	$core->url->getDocument();
-	
+
 	# --BEHAVIOR-- publicAfterDocument
 	$core->callBehavior('publicAfterDocument',$core);
 } catch (Exception $e) {
@@ -153,4 +154,3 @@ try {
 		,__('Something went wrong while loading template file for your blog.')
 		,660);
 }
-?>
\ No newline at end of file
