@@ -11,30 +11,64 @@
 # -- END LICENSE BLOCK -----------------------------------------#
 #
 #
-#        DOT NOT MODIFY THIS FILE !
+#		  DOT NOT MODIFY THIS FILE !
 
 
 
 
+$GLOBALS['__l10n']['Manage every blog configuration directive'] = '';
+$GLOBALS['__l10n']['Akismet interface for Dotclear'] = '';
+$GLOBALS['__l10n']['Generic antispam plugin for Dotclear'] = '';
+$GLOBALS['__l10n']['Manage post attachments'] = '';
+$GLOBALS['__l10n']['Manage your blogroll'] = '';
+$GLOBALS['__l10n']['Configure your Blowup Theme'] = '';
+$GLOBALS['__l10n']['Legacy modules for dotclear'] = '';
+$GLOBALS['__l10n']['Trackback validity check'] = '';
+$GLOBALS['__l10n']['Import and Export your blog'] = '';
+$GLOBALS['__l10n']['Maintain your installation'] = '';
+$GLOBALS['__l10n']['Serve entries as simple web pages'] = '';
+$GLOBALS['__l10n']['Ping services'] = '';
+$GLOBALS['__l10n']['Simple menu for Dotclear'] = '';
+$GLOBALS['__l10n']['Tags for posts'] = '';
+$GLOBALS['__l10n']['Theme Editor'] = '';
+$GLOBALS['__l10n']['Manage every user preference directive'] = '';
+$GLOBALS['__l10n']['Widgets for your blog sidebars'] = '';
+$GLOBALS['__l10n']['Search engine form'] = '';
+$GLOBALS['__l10n']['List of navigation links'] = '';
+$GLOBALS['__l10n']['List of selected entries'] = '';
+$GLOBALS['__l10n']['List of available languages'] = '';
+$GLOBALS['__l10n']['List of categories'] = '';
+$GLOBALS['__l10n']['Feed subscription links (RSS or Atom)'] = '';
+$GLOBALS['__l10n']['List of last entries from feed (RSS or Atom)'] = '';
+$GLOBALS['__l10n']['Simple text'] = '';
+$GLOBALS['__l10n']['List of last entries published'] = '';
+$GLOBALS['__l10n']['List of last comments published'] = '';
+$GLOBALS['__l10n']['Tags cloud'] = '';
+$GLOBALS['__l10n']['List of published pages'] = '';
+$GLOBALS['__l10n']['Blogroll list'] = '';
+$GLOBALS['__l10n']['List of simple menu items'] = '';
+$GLOBALS['__l10n']['Configuration successfully updated'] = '';
 $GLOBALS['__l10n']['no'] = '';
 $GLOBALS['__l10n']['yes'] = '';
-$GLOBALS['__l10n']['Configuration successfully updated'] = '';
-$GLOBALS['__l10n']['Settings definition successfully updated'] = '';
-$GLOBALS['__l10n']['blog settings'] = '';
+$GLOBALS['__l10n']['about:config'] = '';
+$GLOBALS['__l10n']['Settings for %s'] = '';
 $GLOBALS['__l10n']['Value'] = '';
 $GLOBALS['__l10n']['Description'] = '';
 $GLOBALS['__l10n']['Goto:'] = '';
-$GLOBALS['__l10n']['Ok'] = '';
-$GLOBALS['__l10n']['global settings'] = '';
+$GLOBALS['__l10n']['Global settings'] = '';
 $GLOBALS['__l10n']['Akismet spam filter'] = '';
 $GLOBALS['__l10n']['Filtered by %s.'] = '';
+$GLOBALS['__l10n']['Filter configuration have been successfully saved.'] = '';
 $GLOBALS['__l10n']['Akismet API key:'] = '';
 $GLOBALS['__l10n']['API key verified'] = '';
 $GLOBALS['__l10n']['API key not verified'] = '';
 $GLOBALS['__l10n']['Get your own API key'] = '';
 $GLOBALS['__l10n']['Antispam'] = '';
+$GLOBALS['__l10n']['All spam comments older than %s day(s) will be automatically deleted.'] = '';
+$GLOBALS['__l10n']['You can modify this duration in the %s'] = '';
 $GLOBALS['__l10n']['Delete junk comments older than'] = '';
 $GLOBALS['__l10n']['days'] = '';
+$GLOBALS['__l10n']['Set spam filters.'] = '';
 $GLOBALS['__l10n']['IP Blacklist / Whitelist Filter'] = '';
 $GLOBALS['__l10n']['Filtered by %1$s with rule %2$s.'] = '';
 $GLOBALS['__l10n']['IP address has been successfully added.'] = '';
@@ -42,15 +76,15 @@ $GLOBALS['__l10n']['IP addresses have been successfully removed.'] = '';
 $GLOBALS['__l10n']['Blacklist'] = '';
 $GLOBALS['__l10n']['Whitelist'] = '';
 $GLOBALS['__l10n']['Add an IP address: '] = '';
-$GLOBALS['__l10n']['Global IP'] = '';
 $GLOBALS['__l10n']['Global IP (used for all blogs)'] = '';
 $GLOBALS['__l10n']['Add'] = '';
 $GLOBALS['__l10n']['No IP address in list.'] = '';
 $GLOBALS['__l10n']['IP list'] = '';
 $GLOBALS['__l10n']['Local IPs (used only for this blog)'] = '';
-$GLOBALS['__l10n']['Global IPs (used only for this blog)'] = '';
+$GLOBALS['__l10n']['Global IPs (used for all blogs)'] = '';
 $GLOBALS['__l10n']['Checks sender IP address against DNSBL servers'] = '';
 $GLOBALS['__l10n']['Filtered by %1$s with server %2$s.'] = '';
+$GLOBALS['__l10n']['The list of DNSBL servers has been succesfully updated.'] = '';
 $GLOBALS['__l10n']['IP Lookup servers'] = '';
 $GLOBALS['__l10n']['Add here a coma separated list of servers.'] = '';
 $GLOBALS['__l10n']['Checks links in comments against surbl.org'] = '';
@@ -60,7 +94,6 @@ $GLOBALS['__l10n']['Words have been successfully added.'] = '';
 $GLOBALS['__l10n']['Word has been successfully added.'] = '';
 $GLOBALS['__l10n']['Words have been successfully removed.'] = '';
 $GLOBALS['__l10n']['Add a word '] = '';
-$GLOBALS['__l10n']['Global word'] = '';
 $GLOBALS['__l10n']['Global word (used for all blogs)'] = '';
 $GLOBALS['__l10n']['No word in list.'] = '';
 $GLOBALS['__l10n']['List of bad words'] = '';
@@ -80,16 +113,13 @@ $GLOBALS['__l10n']['Spam'] = '';
 $GLOBALS['__l10n']['Ham'] = '';
 $GLOBALS['__l10n']['Filter does not exist.'] = '';
 $GLOBALS['__l10n']['Filter has no user interface.'] = '';
+$GLOBALS['__l10n']['Filters configuration has been successfully saved.'] = '';
 $GLOBALS['__l10n']['%s configuration'] = '';
+$GLOBALS['__l10n']['%s filter configuration'] = '';
+$GLOBALS['__l10n']['Back to filters list'] = '';
 $GLOBALS['__l10n']['Information'] = '';
-$GLOBALS['__l10n']['Spam comments have been successfully deleted.'] = '';
 $GLOBALS['__l10n']['Junk comments:'] = '';
 $GLOBALS['__l10n']['Published comments:'] = '';
-$GLOBALS['__l10n']['Delete all spams'] = '';
-$GLOBALS['__l10n']['All spam comments older than %s day(s) will be automatically deleted.'] = '';
-$GLOBALS['__l10n']['You can modify this duration in the %s'] = '';
-$GLOBALS['__l10n']['Blog preferences'] = '';
-$GLOBALS['__l10n']['Filters configuration has been successfully saved.'] = '';
 $GLOBALS['__l10n']['Available spam filters'] = '';
 $GLOBALS['__l10n']['Order'] = '';
 $GLOBALS['__l10n']['Active'] = '';
@@ -101,25 +131,32 @@ $GLOBALS['__l10n']['Syndication'] = '';
 $GLOBALS['__l10n']['Junk comments RSS feed'] = '';
 $GLOBALS['__l10n']['Published comments RSS feed'] = '';
 $GLOBALS['__l10n']['Attachments'] = '';
+$GLOBALS['__l10n']['Attachments (%d)'] = '';
 $GLOBALS['__l10n']['remove'] = '';
 $GLOBALS['__l10n']['No attachment.'] = '';
 $GLOBALS['__l10n']['Add files to this entry'] = '';
 $GLOBALS['__l10n']['Blogroll'] = '';
 $GLOBALS['__l10n']['manage blogroll'] = '';
 $GLOBALS['__l10n']['Links'] = '';
+$GLOBALS['__l10n']['Title (optional)'] = '';
 $GLOBALS['__l10n']['All categories'] = '';
+$GLOBALS['__l10n']['Display on:'] = '';
+$GLOBALS['__l10n']['All pages'] = '';
 $GLOBALS['__l10n']['Home page only'] = '';
+$GLOBALS['__l10n']['Except on home page'] = '';
+$GLOBALS['__l10n']['Content only'] = '';
+$GLOBALS['__l10n']['CSS class:'] = '';
 $GLOBALS['__l10n']['You must provide a link title'] = '';
 $GLOBALS['__l10n']['You must provide a link URL'] = '';
 $GLOBALS['__l10n']['You need to provide a XBEL or OPML file.'] = '';
 $GLOBALS['__l10n']['File is not in XML format.'] = '';
 $GLOBALS['__l10n']['No such link or title'] = '';
-$GLOBALS['__l10n']['Return to blogroll'] = '';
-$GLOBALS['__l10n']['Category has been successfully updated'] = '';
-$GLOBALS['__l10n']['Edit category'] = '';
 $GLOBALS['__l10n']['Link has been successfully updated'] = '';
+$GLOBALS['__l10n']['Category has been successfully updated'] = '';
+$GLOBALS['__l10n']['Return to blogroll'] = '';
+$GLOBALS['__l10n']['Edit category'] = '';
 $GLOBALS['__l10n']['Edit link'] = '';
-$GLOBALS['__l10n']['XFN'] = '';
+$GLOBALS['__l10n']['XFN information'] = '';
 $GLOBALS['__l10n']['_xfn_Me'] = 'Me';
 $GLOBALS['__l10n']['_xfn_Another link for myself'] = 'Another link for myself';
 $GLOBALS['__l10n']['_xfn_Friendship'] = 'Friendship';
@@ -146,12 +183,12 @@ $GLOBALS['__l10n']['_xfn_Crush'] = 'Crush';
 $GLOBALS['__l10n']['_xfn_Date'] = 'Date';
 $GLOBALS['__l10n']['_xfn_Sweetheart'] = 'Sweetheart';
 $GLOBALS['__l10n']['Nothing to import'] = '';
+$GLOBALS['__l10n']['links have been successfully imported.'] = '';
 $GLOBALS['__l10n']['Import operation cancelled.'] = '';
-$GLOBALS['__l10n']['Items order has been successfully updated'] = '';
-$GLOBALS['__l10n']['Items have been successfully removed.'] = '';
 $GLOBALS['__l10n']['Link has been successfully created.'] = '';
 $GLOBALS['__l10n']['category has been successfully created.'] = '';
-$GLOBALS['__l10n']['links have been successfully imported.'] = '';
+$GLOBALS['__l10n']['Items have been successfully removed.'] = '';
+$GLOBALS['__l10n']['Items order has been successfully updated'] = '';
 $GLOBALS['__l10n']['URL'] = '';
 $GLOBALS['__l10n']['Lang'] = '';
 $GLOBALS['__l10n']['select this link'] = '';
@@ -168,12 +205,14 @@ $GLOBALS['__l10n']['Medium linear gradient'] = '';
 $GLOBALS['__l10n']['Dark linear gradient'] = '';
 $GLOBALS['__l10n']['Solid color'] = '';
 $GLOBALS['__l10n']['Custom...'] = '';
+$GLOBALS['__l10n']['Theme configuration has been successfully updated.'] = '';
 $GLOBALS['__l10n']['Blowup configuration'] = '';
 $GLOBALS['__l10n']['Predefined styles'] = '';
 $GLOBALS['__l10n']['Apply code'] = '';
 $GLOBALS['__l10n']['Choose a predefined style'] = '';
+$GLOBALS['__l10n']['Back to Blog appearance'] = '';
 $GLOBALS['__l10n']['For the following reasons, images cannot be created. You won\'t be able to change some background properties.'] = '';
-$GLOBALS['__l10n']['Theme configuration has been successfully updated.'] = '';
+$GLOBALS['__l10n']['Customization'] = '';
 $GLOBALS['__l10n']['General'] = '';
 $GLOBALS['__l10n']['Background color:'] = '';
 $GLOBALS['__l10n']['Background color fill:'] = '';
@@ -231,13 +270,15 @@ $GLOBALS['__l10n']['Footer color:'] = '';
 $GLOBALS['__l10n']['Footer links color:'] = '';
 $GLOBALS['__l10n']['Footer background color:'] = '';
 $GLOBALS['__l10n']['Additional CSS'] = '';
+$GLOBALS['__l10n']['Any additional CSS styles (must be written using the CSS syntax):'] = '';
 $GLOBALS['__l10n']['Configuration import / export'] = '';
 $GLOBALS['__l10n']['You can share your configuration using the following code. To apply a configuration, paste the code, click on "Apply code" and save.'] = '';
 $GLOBALS['__l10n']['Copy this code:'] = '';
 $GLOBALS['__l10n']['default'] = '';
-$GLOBALS['__l10n']['At least one of the following functions is not available: imagecreatetruecolor, imagepng & imagecreatefrompng.'] = '';
 $GLOBALS['__l10n']['The \'public\' directory does not exist.'] = '';
 $GLOBALS['__l10n']['The \'%s\' directory cannot be modified.'] = '';
+$GLOBALS['__l10n']['Unable to create css file.'] = '';
+$GLOBALS['__l10n']['At least one of the following functions is not available: imagecreatetruecolor, imagepng & imagecreatefrompng.'] = '';
 $GLOBALS['__l10n']['Unable to create images.'] = '';
 $GLOBALS['__l10n']['Invalid file type.'] = '';
 $GLOBALS['__l10n']['Uploaded image is not 800 pixels wide.'] = '';
@@ -247,11 +288,14 @@ $GLOBALS['__l10n']['Import/Export'] = '';
 $GLOBALS['__l10n']['Flat file export'] = '';
 $GLOBALS['__l10n']['Exports a blog or a full Dotclear installation to flat file.'] = '';
 $GLOBALS['__l10n']['Export file not found.'] = '';
-$GLOBALS['__l10n']['Export a blog'] = '';
+$GLOBALS['__l10n']['Failed to compress export file.'] = '';
+$GLOBALS['__l10n']['Single blog'] = '';
 $GLOBALS['__l10n']['This will create an export of your current blog: %s'] = '';
-$GLOBALS['__l10n']['Export'] = '';
+$GLOBALS['__l10n']['Compress file'] = '';
 $GLOBALS['__l10n']['You may also want to download your media directory as a zip file'] = '';
-$GLOBALS['__l10n']['Export all content'] = '';
+$GLOBALS['__l10n']['Export'] = '';
+$GLOBALS['__l10n']['Multiple blogs'] = '';
+$GLOBALS['__l10n']['This will create an export of all the content of your database.'] = '';
 $GLOBALS['__l10n']['Congratulation!'] = '';
 $GLOBALS['__l10n']['Your blog has been successfully imported. Welcome on Dotclear 2!'] = '';
 $GLOBALS['__l10n']['Why don\'t you blog this now?'] = '';
@@ -259,9 +303,8 @@ $GLOBALS['__l10n']['or'] = '';
 $GLOBALS['__l10n']['visit your dashboard'] = '';
 $GLOBALS['__l10n']['Dotclear 1.2 import'] = '';
 $GLOBALS['__l10n']['Import a Dotclear 1.2 installation into your current blog.'] = '';
-$GLOBALS['__l10n']['This will import your Dotclear 1.2 content as new content in the current blog: %s.'] = '';
+$GLOBALS['__l10n']['Import the content of a Dotclear 1.2\'s blog in the current blog: %s.'] = '';
 $GLOBALS['__l10n']['Please note that this process will empty your categories, blogroll, entries and comments on the current blog.'] = '';
-$GLOBALS['__l10n']['Depending on the size of your blog, it could take a few minutes.'] = '';
 $GLOBALS['__l10n']['General information'] = '';
 $GLOBALS['__l10n']['Import my blog now'] = '';
 $GLOBALS['__l10n']['We first need some information about your old Dotclear 1.2 installation.'] = '';
@@ -275,31 +318,33 @@ $GLOBALS['__l10n']['Please read carefully'] = '';
 $GLOBALS['__l10n']['Every newly imported user has received a random password and will need to ask for a new one by following the "I forgot my password" link on the login page (Their registered email address has to be valid.)'] = '';
 $GLOBALS['__l10n']['Please note that Dotclear 2 has a new URL layout. You can avoid broken links by installing <a href="%s">DC1 redirect</a> plugin and activate it in your blog configuration.'] = '';
 $GLOBALS['__l10n']['next step'] = '';
+$GLOBALS['__l10n']['Depending on the size of your blog, it could take a few minutes.'] = '';
 $GLOBALS['__l10n']['Dotclear tables not found'] = '';
-$GLOBALS['__l10n']['Feed import'] = '';
-$GLOBALS['__l10n']['Imports a feed as new entries.'] = '';
+$GLOBALS['__l10n']['RSS or Atom feed import'] = '';
+$GLOBALS['__l10n']['Add a feed content to the blog.'] = '';
 $GLOBALS['__l10n']['Cannot retrieve feed URL.'] = '';
 $GLOBALS['__l10n']['No items in feed.'] = '';
 $GLOBALS['__l10n']['Content successfully imported.'] = '';
-$GLOBALS['__l10n']['Import from a feed'] = '';
-$GLOBALS['__l10n']['This will import a feed (RSS or Atom) a as new content in the current blog: %s.'] = '';
+$GLOBALS['__l10n']['Add a feed content to the current blog: <strong>%s</strong>.'] = '';
 $GLOBALS['__l10n']['Feed URL:'] = '';
 $GLOBALS['__l10n']['Flat file import'] = '';
 $GLOBALS['__l10n']['Imports a blog or a full Dotclear installation from flat file.'] = '';
 $GLOBALS['__l10n']['Single blog successfully imported.'] = '';
 $GLOBALS['__l10n']['Are you sure you want to import a full backup file?'] = '';
-$GLOBALS['__l10n']['Import a single blog'] = '';
-$GLOBALS['__l10n']['This will import a single blog backup as new content in the current blog: %s.'] = '';
+$GLOBALS['__l10n']['This will import a single blog backup as new content in the current blog: <strong>%s</strong>.'] = '';
 $GLOBALS['__l10n']['Upload a backup file'] = '';
+$GLOBALS['__l10n']['maximum size %s'] = '';
 $GLOBALS['__l10n']['or pick up a local file in your public directory'] = '';
-$GLOBALS['__l10n']['Import a full backup file'] = '';
-$GLOBALS['__l10n']['Warning: This will reset all the content of your database, except users.'] = '';
+$GLOBALS['__l10n']['This will reset all the content of your database, except users.'] = '';
+$GLOBALS['__l10n']['Another file with same name exists.'] = '';
+$GLOBALS['__l10n']['Failed to extract backup file.'] = '';
+$GLOBALS['__l10n']['No backup in compressed file.'] = '';
 $GLOBALS['__l10n']['WordPress import'] = '';
 $GLOBALS['__l10n']['Import a WordPress installation into your current blog.'] = '';
 $GLOBALS['__l10n']['This will import your WordPress content as new content in the current blog: %s.'] = '';
 $GLOBALS['__l10n']['We first need some information about your old WordPress installation.'] = '';
 $GLOBALS['__l10n']['WordPress and Dotclear\'s handling of categories are quite different. You can assign several categories to a single post in WordPress. In the Dotclear world, we see it more like "One category, several tags." Therefore Dotclear can only import one category per post and will chose the lowest numbered one. If you want to keep a trace of every category, you can import them as tags, with an optional prefix.'] = '';
-$GLOBALS['__l10n']['On the other hand, in WordPress, a post can not be uncategorized, and a default installation has a first category labelised <i>"Uncategorized"</i>. If you did not change that category, you can just ignore it while importing your blog, as Dotclear allows you to actually keep your posts uncategorized.'] = '';
+$GLOBALS['__l10n']['On the other hand, in WordPress, a post can not be uncategorized, and a default installation has a first category labelised <i>"Uncategorized"</i>.If you did not change that category, you can just ignore it while importing your blog, as Dotclear allows you to actually keep your posts uncategorized.'] = '';
 $GLOBALS['__l10n']['Ignore the first category:'] = '';
 $GLOBALS['__l10n']['Import lowest numbered category on posts:'] = '';
 $GLOBALS['__l10n']['Import all categories as tags:'] = '';
@@ -313,72 +358,142 @@ $GLOBALS['__l10n']['No file to read.'] = '';
 $GLOBALS['__l10n']['File is not a DotClear backup.'] = '';
 $GLOBALS['__l10n']['File is not a single blog export.'] = '';
 $GLOBALS['__l10n']['File is not a full export.'] = '';
-$GLOBALS['__l10n']['The backup file does not appear to be well formed.'] = '';
+$GLOBALS['__l10n']['ID of "%3$s" does not match on record "%1$s" at line %2$s of backup file.'] = '';
+$GLOBALS['__l10n']['Database export'] = '';
+$GLOBALS['__l10n']['Download database of current blog'] = '';
+$GLOBALS['__l10n']['Download database of all blogs'] = '';
 $GLOBALS['__l10n']['Please wait...'] = '';
+$GLOBALS['__l10n']['Export functions are in the page %s.'] = '';
 $GLOBALS['__l10n']['Maintenance'] = '';
-$GLOBALS['__l10n']['Optimization successful.'] = '';
-$GLOBALS['__l10n']['Comments and trackback counted.'] = '';
+$GLOBALS['__l10n']['Servicing'] = '';
+$GLOBALS['__l10n']['Tools to maintain the performance of your blogs.'] = '';
+$GLOBALS['__l10n']['Backup'] = '';
+$GLOBALS['__l10n']['Tools to back up your content.'] = '';
+$GLOBALS['__l10n']['Development'] = '';
+$GLOBALS['__l10n']['Tools to assist in development of plugins, themes and core.'] = '';
+$GLOBALS['__l10n']['Optimize'] = '';
+$GLOBALS['__l10n']['Count and index'] = '';
+$GLOBALS['__l10n']['Purge'] = '';
+$GLOBALS['__l10n']['Other'] = '';
+$GLOBALS['__l10n']['Current blog'] = '';
+$GLOBALS['__l10n']['All blogs'] = '';
+$GLOBALS['__l10n']['Maintain translations'] = '';
+$GLOBALS['__l10n']['Translations'] = '';
+$GLOBALS['__l10n']['One task to execute'][0] = '';
+$GLOBALS['__l10n']['One task to execute'][1] = '';
+$GLOBALS['__l10n']['This task has never been executed.'] = '';
+$GLOBALS['__l10n']['Last execution of this task was on %s.'] = '';
+$GLOBALS['__l10n']['There is a task to execute.'][0] = '';
+$GLOBALS['__l10n']['There is a task to execute.'][1] = '';
+$GLOBALS['__l10n']['Manage tasks'] = '';
+$GLOBALS['__l10n']['Display overdue tasks counter on maintenance dashboard icon'] = '';
+$GLOBALS['__l10n']['Display overdue tasks list on dashboard items'] = '';
+$GLOBALS['__l10n']['Failed to execute task.'] = '';
+$GLOBALS['__l10n']['Task successfully executed.'] = '';
+$GLOBALS['__l10n']['Empty templates cache directory'] = '';
 $GLOBALS['__l10n']['Templates cache directory emptied.'] = '';
-$GLOBALS['__l10n']['Logs deleted.'] = '';
-$GLOBALS['__l10n']['Indexing entry %d to %d.'] = '';
-$GLOBALS['__l10n']['next'] = '';
-$GLOBALS['__l10n']['Entries index done.'] = '';
-$GLOBALS['__l10n']['Back'] = '';
+$GLOBALS['__l10n']['Failed to empty templates cache directory.'] = '';
+$GLOBALS['__l10n']['It may be useful to empty this cache when modifying a theme\'s .html or .css files (or when updating a theme or plugin). Notice : with some hosters, the templates cache cannot be emptied with this plugin. You may then have to delete the directory <strong>/cbtpl/</strong> directly on the server with your FTP software.'] = '';
+$GLOBALS['__l10n']['Count again comments and trackbacks'] = '';
+$GLOBALS['__l10n']['Comments and trackback counted.'] = '';
+$GLOBALS['__l10n']['Failed to count comments and trackbacks.'] = '';
+$GLOBALS['__l10n']['Count again comments and trackbacks allows to check their exact numbers. This operation can be useful when importing from another blog platform (or when migrating from dotclear 1 to dotclear 2).'] = '';
+$GLOBALS['__l10n']['Search engine index'] = '';
+$GLOBALS['__l10n']['Index all comments for search engine'] = '';
+$GLOBALS['__l10n']['Next'] = '';
 $GLOBALS['__l10n']['Indexing comment %d to %d.'] = '';
 $GLOBALS['__l10n']['Comments index done.'] = '';
-$GLOBALS['__l10n']['Optimize database room'] = '';
-$GLOBALS['__l10n']['Vacuum tables'] = '';
-$GLOBALS['__l10n']['Counters'] = '';
-$GLOBALS['__l10n']['Reset comments and ping counters'] = '';
-$GLOBALS['__l10n']['Search engine index'] = '';
-$GLOBALS['__l10n']['This may take a very long time'] = '';
-$GLOBALS['__l10n']['Index all posts'] = '';
-$GLOBALS['__l10n']['Index all comments'] = '';
-$GLOBALS['__l10n']['Vacuum logs'] = '';
+$GLOBALS['__l10n']['Failed to index comments.'] = '';
+$GLOBALS['__l10n']['Index all comments and trackbacks in search engine index. This operation is necessary, after importing content in your blog, to use internal search engine, on public and private pages.'] = '';
+$GLOBALS['__l10n']['Index all entries for search engine'] = '';
+$GLOBALS['__l10n']['Indexing entry %d to %d.'] = '';
+$GLOBALS['__l10n']['Entries index done.'] = '';
+$GLOBALS['__l10n']['Failed to index entries.'] = '';
+$GLOBALS['__l10n']['Index all entries in search engine index. This operation is necessary, after importing content in your blog, to use internal search engine, on public and private pages.'] = '';
 $GLOBALS['__l10n']['Delete all logs'] = '';
-$GLOBALS['__l10n']['Empty templates cache directory'] = '';
-$GLOBALS['__l10n']['Empty directory'] = '';
-$GLOBALS['__l10n']['Pages'] = '';
+$GLOBALS['__l10n']['Logs deleted.'] = '';
+$GLOBALS['__l10n']['Failed to delete logs.'] = '';
+$GLOBALS['__l10n']['Logs record all activity and connection to your blog history. Unless you need to keep this history, consider deleting these logs from time to time.'] = '';
+$GLOBALS['__l10n']['Entries metadata'] = '';
+$GLOBALS['__l10n']['Synchronize entries metadata'] = '';
+$GLOBALS['__l10n']['Synchronize entry %d to %d.'] = '';
+$GLOBALS['__l10n']['Entries metadata synchronize done.'] = '';
+$GLOBALS['__l10n']['Failed to synchronize entries metadata.'] = '';
+$GLOBALS['__l10n']['Synchronize all entries metadata could be useful after importing content in your blog or do bad operation on database tables.'] = '';
+$GLOBALS['__l10n']['Optimise database'] = '';
+$GLOBALS['__l10n']['optimize tables'] = '';
+$GLOBALS['__l10n']['Optimization successful.'] = '';
+$GLOBALS['__l10n']['Failed to optimize tables.'] = '';
+$GLOBALS['__l10n']['After numerous delete or update operations on Dotclear\'s database, it gets fragmented. Optimizing will allow to defragment it. It has no incidence on your data\'s integrity. It is recommended to optimize before any blog export.'] = '';
+$GLOBALS['__l10n']['Download media folder of current blog'] = '';
+$GLOBALS['__l10n']['It may be useful to backup your media folder. This compress all content of media folder into a single zip file. Notice : with some hosters, the media folder cannot be compressed with this plugin if it is too big.'] = '';
+$GLOBALS['__l10n']['Download active theme of current blog'] = '';
+$GLOBALS['__l10n']['It may be useful to backup the active theme before any change or update. This compress theme folder into a single zip file.'] = '';
+$GLOBALS['__l10n']['Maintenance plugin has been successfully configured.'] = '';
+$GLOBALS['__l10n']['Never'] = '';
+$GLOBALS['__l10n']['Every week'] = '';
+$GLOBALS['__l10n']['Every two weeks'] = '';
+$GLOBALS['__l10n']['Every month'] = '';
+$GLOBALS['__l10n']['Every two months'] = '';
+$GLOBALS['__l10n']['You have not sufficient permissions to view this page.'] = '';
+$GLOBALS['__l10n']['You should execute it now.'] = '';
+$GLOBALS['__l10n']['Execute task'] = '';
+$GLOBALS['__l10n']['This may take a very long time.'] = '';
+$GLOBALS['__l10n']['Alert settings'] = '';
+$GLOBALS['__l10n']['Activation'] = '';
+$GLOBALS['__l10n']['Display alert messages on late tasks'] = '';
+$GLOBALS['__l10n']['You can place list of late tasks on your %s.'] = '';
+$GLOBALS['__l10n']['Frequency'] = '';
+$GLOBALS['__l10n']['Use one recall time for all tasks'] = '';
+$GLOBALS['__l10n']['Recall time for all tasks:'] = '';
+$GLOBALS['__l10n']['Use one recall time per task'] = '';
+$GLOBALS['__l10n']['New page'] = '';
 $GLOBALS['__l10n']['%d page'] = '';
 $GLOBALS['__l10n']['%d pages'] = '';
 $GLOBALS['__l10n']['manage pages'] = '';
+$GLOBALS['__l10n']['My first page'] = '';
+$GLOBALS['__l10n']['This is your first page. When you\'re ready to blog, log in to edit or delete it.'] = '';
 $GLOBALS['__l10n']['Published on'] = '';
 $GLOBALS['__l10n']['This page\'s comments feed'] = '';
 $GLOBALS['__l10n']['You must provide a valid email address.'] = '';
 $GLOBALS['__l10n']['Page title'] = '';
 $GLOBALS['__l10n']['Page position'] = '';
 $GLOBALS['__l10n']['Publication date'] = '';
+$GLOBALS['__l10n']['Pages actions'] = '';
+$GLOBALS['__l10n']['Back to pages list'] = '';
+$GLOBALS['__l10n']['Selected pages have been successfully reordered.'] = '';
 $GLOBALS['__l10n']['No page'] = '';
-$GLOBALS['__l10n']['select this page'] = '';
+$GLOBALS['__l10n']['Hidden'] = '';
+$GLOBALS['__l10n']['Select this page'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete selected pages?'] = '';
-$GLOBALS['__l10n']['New page'] = '';
+$GLOBALS['__l10n']['Selected pages have been successfully updated.'] = '';
+$GLOBALS['__l10n']['Selected pages have been successfully deleted.'] = '';
 $GLOBALS['__l10n']['Selected pages action:'] = '';
+$GLOBALS['__l10n']['To rearrange pages order, change number at the begining of the line, then click on “Save pages order” button.'] = '';
+$GLOBALS['__l10n']['To rearrange pages order, move items by drag and drop, then click on “Save pages order” button.'] = '';
+$GLOBALS['__l10n']['Save pages order'] = '';
 $GLOBALS['__l10n']['This page does not exist.'] = '';
 $GLOBALS['__l10n']['Edit page'] = '';
-$GLOBALS['__l10n']['next page'] = '';
-$GLOBALS['__l10n']['previous page'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete this page?'] = '';
 $GLOBALS['__l10n']['Page has been successfully updated.'] = '';
 $GLOBALS['__l10n']['Page has been successfully created.'] = '';
 $GLOBALS['__l10n']['Go to this page on the site'] = '';
-$GLOBALS['__l10n']['Page status:'] = '';
-$GLOBALS['__l10n']['Page position:'] = '';
-$GLOBALS['__l10n']['Page lang:'] = '';
-$GLOBALS['__l10n']['Page password:'] = '';
+$GLOBALS['__l10n']['Page status'] = '';
+$GLOBALS['__l10n']['Page language'] = '';
+$GLOBALS['__l10n']['Hide in widget Pages'] = '';
 $GLOBALS['__l10n']['Warning: If you set the URL manually, it may conflict with another page.'] = '';
-$GLOBALS['__l10n']['Add files to this page'] = '';
+$GLOBALS['__l10n']['Introduction to the page.'] = '';
+$GLOBALS['__l10n']['Select this comment'] = '';
 $GLOBALS['__l10n']['Pings'] = '';
-$GLOBALS['__l10n']['Pings configuration'] = '';
 $GLOBALS['__l10n']['Settings have been successfully updated.'] = '';
+$GLOBALS['__l10n']['Pings configuration'] = '';
 $GLOBALS['__l10n']['Activate pings extension'] = '';
 $GLOBALS['__l10n']['Service name:'] = '';
 $GLOBALS['__l10n']['Service URI:'] = '';
-$GLOBALS['__l10n']['error'] = '';
+$GLOBALS['__l10n']['Error'] = '';
 $GLOBALS['__l10n']['Test ping services'] = '';
 $GLOBALS['__l10n']['Check all'] = '';
-$GLOBALS['__l10n']['Pings:'] = '';
 $GLOBALS['__l10n']['Simple menu'] = '';
-$GLOBALS['__l10n']['Menu'] = '';
 $GLOBALS['__l10n']['All months'] = '';
 $GLOBALS['__l10n']['All tags'] = '';
 $GLOBALS['__l10n']['Home'] = '';
@@ -393,13 +508,16 @@ $GLOBALS['__l10n']['Recent Posts from this category'] = '';
 $GLOBALS['__l10n']['Archives'] = '';
 $GLOBALS['__l10n']['Posts from %s'] = '';
 $GLOBALS['__l10n']['Recent posts for %s tag'] = '';
+$GLOBALS['__l10n']['Menu item has been successfully added.'] = '';
 $GLOBALS['__l10n']['Label and URL of menu item are mandatory.'] = '';
+$GLOBALS['__l10n']['Menu items have been successfully removed.'] = '';
 $GLOBALS['__l10n']['No menu items selected.'] = '';
 $GLOBALS['__l10n']['Label is mandatory.'] = '';
 $GLOBALS['__l10n']['URL is mandatory.'] = '';
-$GLOBALS['__l10n']['Menu item has been successfully added.'] = '';
-$GLOBALS['__l10n']['Menu items have been successfully removed.'] = '';
 $GLOBALS['__l10n']['Menu items have been successfully updated.'] = '';
+$GLOBALS['__l10n']['Step #1'] = '';
+$GLOBALS['__l10n']['Step #2'] = '';
+$GLOBALS['__l10n']['Step #3'] = '';
 $GLOBALS['__l10n']['Add item'] = '';
 $GLOBALS['__l10n']['Select type'] = '';
 $GLOBALS['__l10n']['Type of item menu:'] = '';
@@ -418,26 +536,29 @@ $GLOBALS['__l10n']['Menu items list'] = '';
 $GLOBALS['__l10n']['Update menu'] = '';
 $GLOBALS['__l10n']['Delete selected menu items'] = '';
 $GLOBALS['__l10n']['Are you sure you want to remove selected menu items?'] = '';
-$GLOBALS['__l10n']['Currently no menu items'] = '';
-$GLOBALS['__l10n']['Tags:'] = '';
+$GLOBALS['__l10n']['No menu items so far.'] = '';
+$GLOBALS['__l10n']['Add tags'] = '';
+$GLOBALS['__l10n']['Remove tags'] = '';
+$GLOBALS['__l10n']['Tag has been successfully added to selected entries'][0] = '';
+$GLOBALS['__l10n']['Tag has been successfully added to selected entries'][1] = '';
+$GLOBALS['__l10n']['Add tags to this selection'] = '';
 $GLOBALS['__l10n']['Are you sure you want to remove this %s?'] = '';
 $GLOBALS['__l10n']['Add a %s to this entry'] = '';
 $GLOBALS['__l10n']['Choose from list'] = '';
 $GLOBALS['__l10n']['all'] = '';
-$GLOBALS['__l10n']['Tag'] = '';
+$GLOBALS['__l10n']['Enter tags separated by coma'] = '';
 $GLOBALS['__l10n']['used in %e - frequency %p%'] = '';
 $GLOBALS['__l10n']['entry'] = '';
 $GLOBALS['__l10n']['entries'] = '';
-$GLOBALS['__l10n']['Enter tags separated by coma'] = '';
-$GLOBALS['__l10n']['Add tags'] = '';
-$GLOBALS['__l10n']['Remove tags'] = '';
-$GLOBALS['__l10n']['Add tags to entries'] = '';
 $GLOBALS['__l10n']['Tags to add:'] = '';
-$GLOBALS['__l10n']['Remove selected tags from entries'] = '';
+$GLOBALS['__l10n']['Tag has been successfully removed from selected entries'][0] = '';
+$GLOBALS['__l10n']['Tag has been successfully removed from selected entries'][1] = '';
 $GLOBALS['__l10n']['No tags for selected entries'] = '';
+$GLOBALS['__l10n']['Remove selected tags from this selection'] = '';
 $GLOBALS['__l10n']['Following tags have been found in selected entries:'] = '';
-$GLOBALS['__l10n']['short'] = '';
-$GLOBALS['__l10n']['extended'] = '';
+$GLOBALS['__l10n']['Tag'] = '';
+$GLOBALS['__l10n']['Short'] = '';
+$GLOBALS['__l10n']['Extended'] = '';
 $GLOBALS['__l10n']['Tags list format:'] = '';
 $GLOBALS['__l10n']['This tag\'s comments Atom feed'] = '';
 $GLOBALS['__l10n']['This tag\'s entries Atom feed'] = '';
@@ -445,17 +566,16 @@ $GLOBALS['__l10n']['Limit (empty means no limit):'] = '';
 $GLOBALS['__l10n']['Entries count'] = '';
 $GLOBALS['__l10n']['Tag name'] = '';
 $GLOBALS['__l10n']['Link to all tags:'] = '';
-$GLOBALS['__l10n']['Edit tag'] = '';
 $GLOBALS['__l10n']['Tag has been successfully renamed'] = '';
-$GLOBALS['__l10n']['Back to tags list'] = '';
-$GLOBALS['__l10n']['Actions for this tag'] = '';
-$GLOBALS['__l10n']['Edit tag name:'] = '';
-$GLOBALS['__l10n']['Rename'] = '';
-$GLOBALS['__l10n']['Delete this tag:'] = '';
-$GLOBALS['__l10n']['List of entries with this tag'] = '';
 $GLOBALS['__l10n']['Tag has been successfully removed'] = '';
+$GLOBALS['__l10n']['Are you sure you want to remove tag: “%s”?'] = '';
+$GLOBALS['__l10n']['Back to tags list'] = '';
+$GLOBALS['__l10n']['Rename'] = '';
+$GLOBALS['__l10n']['Delete this tag'] = '';
+$GLOBALS['__l10n']['List of entries with the tag “%s”'] = '';
 $GLOBALS['__l10n']['No tags on this blog.'] = '';
-$GLOBALS['__l10n']['Theme Editor'] = '';
+$GLOBALS['__l10n']['Edit theme files'] = '';
+$GLOBALS['__l10n']['Syntax highlighting in theme editor'] = '';
 $GLOBALS['__l10n']['No file'] = '';
 $GLOBALS['__l10n']['File does not exist.'] = '';
 $GLOBALS['__l10n']['File %s is not readable'] = '';
@@ -472,10 +592,11 @@ $GLOBALS['__l10n']['This file is not writable. Please check your theme files per
 $GLOBALS['__l10n']['Templates files'] = '';
 $GLOBALS['__l10n']['CSS files'] = '';
 $GLOBALS['__l10n']['JavaScript files'] = '';
+$GLOBALS['__l10n']['Locales files'] = '';
 $GLOBALS['__l10n']['Preferences successfully updated'] = '';
-$GLOBALS['__l10n']['Preferences definition successfully updated'] = '';
-$GLOBALS['__l10n']['user preferences'] = '';
-$GLOBALS['__l10n']['global preferences'] = '';
+$GLOBALS['__l10n']['user:preferences'] = '';
+$GLOBALS['__l10n']['User preferences'] = '';
+$GLOBALS['__l10n']['Global preferences'] = '';
 $GLOBALS['__l10n']['Presentation widgets'] = '';
 $GLOBALS['__l10n']['Search engine'] = '';
 $GLOBALS['__l10n']['Navigation links'] = '';
@@ -483,6 +604,8 @@ $GLOBALS['__l10n']['Selected entries'] = '';
 $GLOBALS['__l10n']['Best of me'] = '';
 $GLOBALS['__l10n']['Blog languages'] = '';
 $GLOBALS['__l10n']['With entries counts'] = '';
+$GLOBALS['__l10n']['Include sub cats in count'] = '';
+$GLOBALS['__l10n']['Include empty categories'] = '';
 $GLOBALS['__l10n']['Subscribe links'] = '';
 $GLOBALS['__l10n']['Subscribe'] = '';
 $GLOBALS['__l10n']['Feeds type:'] = '';
@@ -503,9 +626,12 @@ $GLOBALS['__l10n']['Comments feed'] = '';
 $GLOBALS['__l10n']['navigation'] = '';
 $GLOBALS['__l10n']['extra'] = '';
 $GLOBALS['__l10n']['custom'] = '';
+$GLOBALS['__l10n']['empty string'] = '';
 $GLOBALS['__l10n']['Widgets'] = '';
 $GLOBALS['__l10n']['Are you sure you want to reset sidebars?'] = '';
 $GLOBALS['__l10n']['Available widgets'] = '';
+$GLOBALS['__l10n']['Drag widgets from this list to one of the sidebars, for add.'] = '';
+$GLOBALS['__l10n']['order'] = '';
 $GLOBALS['__l10n']['Append to:'] = '';
 $GLOBALS['__l10n']['Add widgets to sidebars'] = '';
 $GLOBALS['__l10n']['Navigation sidebar'] = '';
@@ -513,21 +639,15 @@ $GLOBALS['__l10n']['Extra sidebar'] = '';
 $GLOBALS['__l10n']['Custom sidebar'] = '';
 $GLOBALS['__l10n']['Update sidebars'] = '';
 $GLOBALS['__l10n']['Reset sidebars'] = '';
-$GLOBALS['__l10n']['Use of widgets'] = '';
-$GLOBALS['__l10n']['Widgets may be used to add various blocks of content to be displayed on your public pages. To add a widget, drag it from the Available widgets list on the left to one of the sidebars on the right of this page. You can order your widgets in a sidebar by dragging them up or down. You must update sidebars to apply your changes.'] = '';
-$GLOBALS['__l10n']['Once included in a sidebar, widgets have configuration options that you can reach by clicking on the + sign next to their name.'] = '';
-$GLOBALS['__l10n']['Reset sidebars to get back to default widgets installation.'] = '';
-$GLOBALS['__l10n']['Widget templates tags'] = '';
-$GLOBALS['__l10n']['If you are allowed to edit your theme templates, you can directly add widgets as templates tags, with their own configuration.'] = '';
-$GLOBALS['__l10n']['To add a widget in your template, you need to write code like this:'] = '';
-$GLOBALS['__l10n']['Widget ID'] = '';
-$GLOBALS['__l10n']['Setting name'] = '';
-$GLOBALS['__l10n']['Setting value'] = '';
-$GLOBALS['__l10n']['Here are the following available widgets for your blog:'] = '';
 $GLOBALS['__l10n']['Widget ID:'] = '';
 $GLOBALS['__l10n']['No setting for this widget'] = '';
+$GLOBALS['__l10n']['boolean'] = '';
+$GLOBALS['__l10n']['possible values:'] = '';
+$GLOBALS['__l10n']['listitem'] = '';
+$GLOBALS['__l10n']['string'] = '';
 $GLOBALS['__l10n']['Setting name:'] = '';
-$GLOBALS['__l10n']['No widget.'] = '';
-$GLOBALS['__l10n']['order'] = '';
+$GLOBALS['__l10n']['No widget as far.'] = '';
+$GLOBALS['__l10n']['Up the widget'] = '';
+$GLOBALS['__l10n']['Down the widget'] = '';
 $GLOBALS['__l10n']['Remove widget'] = '';
-?>
\ No newline at end of file
+$GLOBALS['__l10n']['Drag widgets here to remove.'] = '';
