@@ -12,23 +12,32 @@
 if (!defined('DC_CONTEXT_ADMIN')) { return; }
 
 $core->addBehavior('adminDashboardIcons','blogroll_dashboard');
-$core->addBehavior('adminDashboardFavs','blogroll_dashboard_favs');
+$core->addBehavior('adminDashboardFavorites','blogroll_dashboard_favorites');
+$core->addBehavior('adminUsersActionsHeaders','blogroll_users_actions_headers');
+
 function blogroll_dashboard($core,$icons)
 {
 	$icons['blogroll'] = new ArrayObject(array(__('Blogroll'),'plugin.php?p=blogroll','index.php?pf=blogroll/icon.png'));
 }
-function blogroll_dashboard_favs($core,$favs)
+function blogroll_dashboard_favorites($core,$favs)
 {
-	$favs['blogroll'] = new ArrayObject(array('blogroll','Blogroll','plugin.php?p=blogroll',
-		'index.php?pf=blogroll/icon-small.png','index.php?pf=blogroll/icon.png',
-		'usage,contentadmin',null,null));
+	$favs->register('blogroll', array(
+		'title' => __('Blogroll'),
+		'url' => 'plugin.php?p=blogroll',
+		'small-icon' => 'index.php?pf=blogroll/icon-small.png',
+		'large-icon' => 'index.php?pf=blogroll/icon.png',
+		'permissions' => 'usage,contentadmin'
+	));
+}
+function blogroll_users_actions_headers()
+{
+	return dcPage::jsLoad('index.php?pf=blogroll/_users_actions.js');
 }
 
-$_menu['Plugins']->addItem(__('Blogroll'),'plugin.php?p=blogroll','index.php?pf=blogroll/icon-small.png',
+$_menu['Blog']->addItem(__('Blogroll'),'plugin.php?p=blogroll','index.php?pf=blogroll/icon-small.png',
                 preg_match('/plugin.php\?p=blogroll(&.*)?$/',$_SERVER['REQUEST_URI']),
                 $core->auth->check('usage,contentadmin',$core->blog->id));
 
 $core->auth->setPermissionType('blogroll',__('manage blogroll'));
 
 require dirname(__FILE__).'/_widgets.php';
-?>
\ No newline at end of file
