@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -26,7 +26,7 @@ $cat_title = '';
 if (!empty($_POST['import_links']) && !empty($_FILES['links_file']))
 {
 	$default_tab = 'import-links';
-	
+
 	try
 	{
 		files::uploadStatus($_FILES['links_file']);
@@ -34,7 +34,7 @@ if (!empty($_POST['import_links']) && !empty($_FILES['links_file']))
 		if (!move_uploaded_file($_FILES['links_file']['tmp_name'],$ifile)) {
 			throw new Exception(__('Unable to move uploaded file.'));
 		}
-		
+
 		require_once dirname(__FILE__).'/class.dc.importblogroll.php';
 		try {
 			$imported = dcImportBlogroll::loadFile($ifile);
@@ -43,8 +43,8 @@ if (!empty($_POST['import_links']) && !empty($_FILES['links_file']))
 			@unlink($ifile);
 			throw $e;
 		}
-		
-		
+
+
 		if (empty($imported)) {
 			unset($imported);
 			throw new Exception(__('Nothing to import'));
@@ -68,12 +68,14 @@ if (!empty($_POST['import_links_do'])) {
 			$default_tab = 'import-links';
 		}
 	}
-	http::redirect($p_url.'&importlinks=1');	
+
+	dcPage::addSuccessNotice(__('links have been successfully imported.'));
+	http::redirect($p_url);
 }
 
 if (!empty($_POST['cancel_import'])) {
 	$core->error->add(__('Import operation cancelled.'));
-	$default_tab = 'import-links';	
+	$default_tab = 'import-links';
 }
 
 # Add link
@@ -83,10 +85,12 @@ if (!empty($_POST['add_link']))
 	$link_href = $_POST['link_href'];
 	$link_desc = $_POST['link_desc'];
 	$link_lang = $_POST['link_lang'];
-	
+
 	try {
 		$blogroll->addLink($link_title,$link_href,$link_desc,$link_lang);
-		http::redirect($p_url.'&addlink=1');
+
+		dcPage::addSuccessNotice(__('Link has been successfully created.'));
+		http::redirect($p_url);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 		$default_tab = 'add-link';
@@ -97,10 +101,11 @@ if (!empty($_POST['add_link']))
 if (!empty($_POST['add_cat']))
 {
 	$cat_title = $_POST['cat_title'];
-	
+
 	try {
 		$blogroll->addCategory($cat_title);
-		http::redirect($p_url.'&addcat=1');
+		dcPage::addSuccessNotice(__('category has been successfully created.'));
+		http::redirect($p_url);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 		$default_tab = 'add-cat';
@@ -118,9 +123,10 @@ if (!empty($_POST['removeaction']) && !empty($_POST['remove'])) {
 			break;
 		}
 	}
-	
+
 	if (!$core->error->flag()) {
-		http::redirect($p_url.'&removed=1');
+		dcPage::addSuccessNotice(__('Items have been successfully removed.'));
+		http::redirect($p_url);
 	}
 }
 
@@ -138,16 +144,17 @@ if (!empty($_POST['saveorder']) && !empty($order))
 {
 	foreach ($order as $pos => $l) {
 		$pos = ((integer) $pos)+1;
-		
+
 		try {
 			$blogroll->updateOrder($l,$pos);
 		} catch (Exception $e) {
 			$core->error->add($e->getMessage());
 		}
 	}
-	
+
 	if (!$core->error->flag()) {
-		http::redirect($p_url.'&neworder=1');
+		dcPage::addSuccessNotice(__('Items order has been successfully updated'));
+		http::redirect($p_url);
 	}
 }
 
@@ -163,84 +170,35 @@ try {
 <html>
 <head>
   <title><?php echo __('Blogroll'); ?></title>
-  <?php echo dcPage::jsToolMan(); ?>
   <?php echo dcPage::jsConfirmClose('links-form','add-link-form','add-category-form'); ?>
-  <?php 
-	$core->auth->user_prefs->addWorkspace('accessibility'); 
-	$user_dm_nodragdrop = $core->auth->user_prefs->accessibility->nodragdrop;
+  <?php
+	$core->auth->user_prefs->addWorkspace('accessibility');
+	if (!$core->auth->user_prefs->accessibility->nodragdrop) {
+	echo
+		dcPage::jsLoad('js/jquery/jquery-ui.custom.js').
+		dcPage::jsLoad('index.php?pf=blogroll/blogroll.js');
+	}
   ?>
-  <?php if (!$user_dm_nodragdrop) : ?>
-  <script type="text/javascript">
-  //<![CDATA[
-  
-  var dragsort = ToolMan.dragsort();
-  $(function() {
-  	dragsort.makeTableSortable($("#links-list").get(0),
-  	dotclear.sortable.setHandle,dotclear.sortable.saveOrder);
-	
-	$('.checkboxes-helpers').each(function() {
-		dotclear.checkboxesHelpers(this);
-	});
-  });
-  
-  dotclear.sortable = {
-	  setHandle: function(item) {
-		var handle = $(item).find('td.handle').get(0);
-		while (handle.firstChild) {
-			handle.removeChild(handle.firstChild);
-		}
-		
-		item.toolManDragGroup.setHandle(handle);
-		handle.className = handle.className+' handler';
-	  },
-	  
-	  saveOrder: function(item) {
-		var group = item.toolManDragGroup;
-		var order = document.getElementById('links_order');
-		group.register('dragend', function() {
-			order.value = '';
-			items = item.parentNode.getElementsByTagName('tr');
-			
-			for (var i=0; i<items.length; i++) {
-				order.value += items[i].id.substr(2)+',';
-			}
-		});
-	  }
-  };
-  //]]>
-  </script>
-  <?php endif; ?>
   <?php echo dcPage::jsPageTabs($default_tab); ?>
 </head>
 
 <body>
-<h2><?php echo html::escapeHTML($core->blog->name); ?> &rsaquo; <span class="page-title"><?php echo __('Blogroll'); ?></span></h2>
-
 <?php
-if (!empty($_GET['neworder'])) {
-	echo '<p class="message">'.__('Items order has been successfully updated').'</p>';
-}
-
-if (!empty($_GET['removed'])) {
-		echo '<p class="message">'.__('Items have been successfully removed.').'</p>';
-}
-
-if (!empty($_GET['addlink'])) {
-		echo '<p class="message">'.__('Link has been successfully created.').'</p>';
-}
-
-if (!empty($_GET['addcat'])) {
-		echo '<p class="message">'.__('category has been successfully created.').'</p>';
-}
-
-if (!empty($_GET['importlinks'])) {
-		echo '<p class="message">'.__('links have been successfully imported.').'</p>';
-}
+	echo dcPage::breadcrumb(
+		array(
+			html::escapeHTML($core->blog->name) => '',
+			__('Blogroll') => ''
+		)).
+		dcPage::notices();
 ?>
 
-<div class="multi-part" title="<?php echo __('Blogroll'); ?>">
+<div class="multi-part" id="main-list" title="<?php echo __('Blogroll'); ?>">
+
+<?php if (!$rs->isEmpty()) { ?>
+
 <form action="plugin.php" method="post" id="links-form">
-<table class="maximal dragable">
+<div class="table-outer">
+<table class="dragable">
 <thead>
 <tr>
   <th colspan="3"><?php echo __('Title'); ?></th>
@@ -254,13 +212,13 @@ if (!empty($_GET['importlinks'])) {
 while ($rs->fetch())
 {
 	$position = (string) $rs->index()+1;
-	
+
 	echo
 	'<tr class="line" id="l_'.$rs->link_id.'">'.
-	'<td class="handle minimal">'.form::field(array('order['.$rs->link_id.']'),2,5,$position,'','',false,'title="'.__('position').'"').'</td>'.
+	'<td class="handle minimal">'.form::field(array('order['.$rs->link_id.']'),2,5,$position,'position','',false,'title="'.__('position').'"').'</td>'.
 	'<td class="minimal">'.form::checkbox(array('remove[]'),$rs->link_id,'','','',false,'title="'.__('select this link').'"').'</td>';
-	
-	
+
+
 	if ($rs->is_cat)
 	{
 		echo
@@ -276,71 +234,72 @@ while ($rs->fetch())
 		'<td>'.html::escapeHTML($rs->link_href).'</td>'.
 		'<td>'.html::escapeHTML($rs->link_lang).'</td>';
 	}
-	
+
 	echo '</tr>';
 }
 ?>
 </tbody>
-</table>
+</table></div>
+
+<div class="two-cols">
+<p class="col">
 <?php
-	if (!$rs->isEmpty()) {
-		echo
-		'<div class="two-cols">'.
-		'<p class="col">'.form::hidden('links_order','').
-		form::hidden(array('p'),'blogroll').
-		$core->formNonce().
-		'<input type="submit" name="saveorder" value="'.__('Save order').'" /></p>'.
-		
-		'<p class="col right"><input type="submit" class="delete" name="removeaction"'.
-		' value="'.__('Delete selected links').'" '.
-		'onclick="return window.confirm(\''.html::escapeJS(
-			__('Are you sure you want to delete selected links?')).'\');" /></p>'.
-		'</div>';
-	} else {
-		echo
-		'<div><p>'.__('The link list is empty.').'</p></div>';
-	}
+	echo
+	form::hidden('links_order','').
+	form::hidden(array('p'),'blogroll').
+	$core->formNonce();
 ?>
+<input type="submit" name="saveorder" value="<?php echo __('Save order'); ?>" /></p>
+<p class="col right"><input type="submit" class="delete" name="removeaction"
+	 value="<?php echo __('Delete selected links'); ?>"
+	 onclick="return window.confirm('
+	 <?php echo html::escapeJS(__('Are you sure you want to delete selected links?')); ?>');" /></p>
+</div>
 </form>
+
+<?php
+} else {
+	echo '<div><p>'.__('The link list is empty.').'</p></div>';
+}
+?>
+
 </div>
 
 <?php
 echo
 '<div class="multi-part clear" id="add-link" title="'.__('Add a link').'">'.
 '<form action="plugin.php" method="post" id="add-link-form">'.
-'<fieldset class="two-cols"><legend>'.__('Add a new link').'</legend>'.
-'<p class="col"><label for="link_title" class="required"><abbr title="'.__('Required field').'">*</abbr> '.__('Title:').' '.
+'<h3>'.__('Add a new link').'</h3>'.
+'<p class="col"><label for="link_title" class="required"><abbr title="'.__('Required field').'">*</abbr> '.__('Title:').'</label> '.
 form::field('link_title',30,255,$link_title).
-'</label></p>'.
+'</p>'.
 
-'<p class="col"><label for="link_href" class="required"><abbr title="'.__('Required field').'">*</abbr> '.__('URL:').' '.
+'<p class="col"><label for="link_href" class="required"><abbr title="'.__('Required field').'">*</abbr> '.__('URL:').'</label> '.
 form::field('link_href',30,255,$link_href).
-'</label></p>'.
+'</p>'.
 
-'<p class="col"><label for="link_desc">'.__('Description:').' '.
+'<p class="col"><label for="link_desc">'.__('Description:').'</label> '.
 form::field('link_desc',30,255,$link_desc).
-'</label></p>'.
+'</p>'.
 
-'<p class="col"><label for="link_lang">'.__('Language:').' '.
+'<p class="col"><label for="link_lang">'.__('Language:').'</label> '.
 form::field('link_lang',5,5,$link_lang).
-'</label></p>'.
+'</p>'.
 '<p>'.form::hidden(array('p'),'blogroll').
 $core->formNonce().
 '<input type="submit" name="add_link" value="'.__('Save').'" /></p>'.
-'</fieldset>'.
 '</form>'.
 '</div>';
 
 echo
 '<div class="multi-part" id="add-cat" title="'.__('Add a category').'">'.
 '<form action="plugin.php" method="post" id="add-category-form">'.
-'<fieldset><legend>'.__('Add a new category').'</legend>'.
-'<p><label for="cat_title" class=" classic required"><abbr title="'.__('Required field').'">*</abbr> '.__('Title:').' '.
-form::field('cat_title',30,255,$cat_title).'</label> '.
+'<h3>'.__('Add a new category').'</h3>'.
+'<p><label for="cat_title" class=" classic required"><abbr title="'.__('Required field').'">*</abbr> '.__('Title:').'</label> '.
+form::field('cat_title',30,255,$cat_title).' '.
 form::hidden(array('p'),'blogroll').
 $core->formNonce().
 '<input type="submit" name="add_cat" value="'.__('Save').'" /></p>'.
-'</fieldset>'.
 '</form>'.
 '</div>';
 
@@ -349,19 +308,18 @@ echo
 if (!isset($imported)) {
 	echo
 	'<form action="plugin.php" method="post" id="import-links-form" enctype="multipart/form-data">'.
-	'<fieldset><legend>'.__('Import links').'</legend>'.
-	'<p><label for="links_file" class=" classic required"><abbr title="'.__('Required field').'">*</abbr> '.__('OPML or XBEL File:').' '.
-	'<input type="file" id="links_file" name="links_file" /></label></p>'.
+	'<h3>'.__('Import links').'</h3>'.
+	'<p><label for="links_file" class=" classic required"><abbr title="'.__('Required field').'">*</abbr> '.__('OPML or XBEL File:').'</label> '.
+	'<input type="file" id="links_file" name="links_file" /></p>'.
 	'<p>'.form::hidden(array('p'),'blogroll').
 	$core->formNonce().
 	'<input type="submit" name="import_links" value="'.__('Import').'" /></p>'.
-	'</fieldset>'.
 	'</form>';
 }
 else {
 	echo
 	'<form action="plugin.php" method="post" id="import-links-form">'.
-	'<fieldset><legend>'.__('Import links').'</legend>';
+	'<h3>'.__('Import links').'</h3>';
 	if (empty($imported)) {
 		echo '<p>'.__('Nothing to import').'</p>';
 	}
@@ -371,14 +329,14 @@ else {
 		'<th colspan="2">'.__('Title').'</th>'.
 		'<th>'.__('Description').'</th>'.
 		'</tr>';
-		
+
 		$i = 0;
 		foreach ($imported as $entry) {
 			$url   = html::escapeHTML($entry->link);
 			$title = html::escapeHTML($entry->title);
 			$desc  = html::escapeHTML($entry->desc);
-			
-			echo 
+
+			echo
 			'<tr><td>'.form::checkbox(array('entries[]'),$i,'','','').'</td>'.
 			'<td nowrap><a href="'.$url.'">'.$title.'</a>'.
 			'<input type="hidden" name="url['.$i.']" value="'.$url.'" />'.
@@ -386,14 +344,14 @@ else {
 			'</td>'.
 			'<td>'.$desc.
 			'<input type="hidden" name="desc['.$i.']" value="'.$desc.'" />'.
-			'</td></tr>'."\n";			
+			'</td></tr>'."\n";
 			$i++;
 		}
 		echo
 		'</table>'.
 		'<div class="two-cols">'.
 		'<p class="col checkboxes-helpers"></p>'.
-		
+
 		'<p class="col right">'.
 		form::hidden(array('p'),'blogroll').
 		$core->formNonce().
@@ -402,7 +360,6 @@ else {
 		'</div>';
 	}
 	echo
-	'</fieldset>'.
 	'</form>';
 }
 echo '</div>';
@@ -411,4 +368,4 @@ dcPage::helpBlock('blogroll');
 ?>
 
 </body>
-</html>
\ No newline at end of file
+</html>
