@@ -3,7 +3,7 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -18,7 +18,7 @@ $this->registerModule(
 	/* Version */			'1.1',
 	array(
 		'permissions' =>	'usage,contentadmin',
-		'priority' =>		200
+		'priority' =>		200,
+		'type'		=>		'plugin'
 	)
 );
-?>
\ No newline at end of file
