@@ -15,9 +15,10 @@ $this->registerModule(
 	/* Name */			"Tags",
 	/* Description*/		"Tags for posts",
 	/* Author */			"Olivier Meunier",
-	/* Version */			'1.2',
+	/* Version */			'1.2.1',
 	array(
-		'permissions' =>	'usage,contentadmin'
+		'permissions' =>	'usage,contentadmin',
+		'priority' =>		998,
+		'type'		=>		'plugin'
 	)
 );
-?>
\ No newline at end of file
