@@ -11,17 +11,17 @@
 # -- END LICENSE BLOCK -----------------------------------------#
 #
 #
-#        DOT NOT MODIFY THIS FILE !
+#		  DOT NOT MODIFY THIS FILE !
 
 
 
 
-$GLOBALS['__l10n']['Theme configuration upgraded.'] = 'Configuration du thème mise à jour.';
+$GLOBALS['__l10n']['Theme configuration upgraded.'] = 'La configuration du thème a été mise à jour.';
 $GLOBALS['__l10n']['Content'] = 'Contenu';
 $GLOBALS['__l10n']['Header'] = 'Entête';
 $GLOBALS['__l10n']['Hide blog description:'] = 'Cacher la description du blog :';
 $GLOBALS['__l10n']['Logo URL:'] = 'URL du logo :';
-$GLOBALS['__l10n']['To configure the top menu go to the <a href="%s">Simple Menu administration page</a>.'] = 'Pour configurer le menu allez à la <a href="%s">page d\'administration de l\'extension Menu Simple</a>.';
+$GLOBALS['__l10n']['To configure the top menu go to the <a href="%s">Simple Menu administration page</a>.'] = 'Pour configurer le menu allez à la <a href="%s">page d\'administration de Menu Simple</a>.';
 $GLOBALS['__l10n']['Stickers'] = 'Étiquettes';
 $GLOBALS['__l10n']['Stickers (footer)'] = 'Étiquettes (pied de page)';
 $GLOBALS['__l10n']['Entries list types and limits'] = 'Types et limites des listes de billets';
@@ -33,19 +33,19 @@ $GLOBALS['__l10n']['Home (first page)'] = 'Page d\'accueil (première page)';
 $GLOBALS['__l10n']['Home (other pages)'] = 'Page d\'accueil (pages suivantes)';
 $GLOBALS['__l10n']['Entries for a category'] = 'Billets d\'une catégorie';
 $GLOBALS['__l10n']['Entries for a tag'] = 'Billets pour un mot-clé';
-$GLOBALS['__l10n']['Search result entries'] = 'Billets résultants d\'une recherche';
+$GLOBALS['__l10n']['Search result entries'] = 'Billets résultant d\'une recherche';
 $GLOBALS['__l10n']['Month archive entries'] = 'Billets d\'une archive mensuelle';
 $GLOBALS['__l10n']['Title'] = 'Titre';
 $GLOBALS['__l10n']['Short'] = 'Court';
 $GLOBALS['__l10n']['Full'] = 'Complet';
 $GLOBALS['__l10n']['Miscellaneous options'] = 'Options diverses';
-$GLOBALS['__l10n']['Comment preview is not mandatory:'] = 'Prévisualisation du commentaire optionnelle :';
+$GLOBALS['__l10n']['Comment preview is not mandatory:'] = 'Prévisualisation du commentaire non obligatoire :';
 $GLOBALS['__l10n']['Presentation'] = 'Présentation';
 $GLOBALS['__l10n']['General settings'] = 'Paramètres généraux';
 $GLOBALS['__l10n']['Mobile specific settings'] = 'Paramètres spécifiques pour les mobiles';
 $GLOBALS['__l10n']['Blog title'] = 'Titre du blog';
 $GLOBALS['__l10n']['In bold:'] = 'En gras :';
-$GLOBALS['__l10n']['Font size (in em by default):'] = 'Taille de police (en em par défaut) :';
+$GLOBALS['__l10n']['Font size (in em by default):'] = 'Taille du texte courant (en em par défaut) :';
 $GLOBALS['__l10n']['Color:'] = 'Couleur :';
 $GLOBALS['__l10n']['Post title'] = 'Titre des billets';
 $GLOBALS['__l10n']['Titles without link'] = 'Titres sans lien';
@@ -58,8 +58,8 @@ $GLOBALS['__l10n']['Secondary:'] = 'Secondaire :';
 $GLOBALS['__l10n']['none'] = 'aucune';
 $GLOBALS['__l10n']['javascript (Adobe)'] = 'javascript (Adobe)';
 $GLOBALS['__l10n']['stylesheet (Google)'] = 'feuille de style (Google)';
-$GLOBALS['__l10n']['Set main font to default to use webfont below.'] = 'Mettre la police de caractère principale à Défaut pour utiliser la fonte web ci-dessous.';
-$GLOBALS['__l10n']['Set secondary font to default to use webfont below.'] = 'Mettre la police de caractère secondaire à Défaut pour utiliser la fonte web ci-dessous.';
+$GLOBALS['__l10n']['Set main font to Default to use webfont below.'] = 'Mettre la police de caractère principale à Défaut pour utiliser la fonte web ci-dessous.';
+$GLOBALS['__l10n']['Set secondary font to Default to use webfont below.'] = 'Mettre la police de caractère secondaire à Défaut pour utiliser la fonte web ci-dessous.';
 $GLOBALS['__l10n']['Webfont family:'] = 'Famille';
 $GLOBALS['__l10n']['Webfont URL:'] = 'URL de la fonte web';
 $GLOBALS['__l10n']['Webfont API:'] = 'Type d\'API';
@@ -74,4 +74,3 @@ $GLOBALS['__l10n']['Trebuchet MS'] = 'Trebuchet MS';
 $GLOBALS['__l10n']['Impact'] = 'Impact';
 $GLOBALS['__l10n']['Monospace'] = 'Monospace';
 $GLOBALS['__l10n']['ratio %.1f'] = 'ratio %.1f';
-?>
\ No newline at end of file
